# TranslatorAR: A Robust System for Bidirectional Translation Between Arabic and Major Languages

## Abstract

TranslatorAR is an advanced translation software designed to facilitate seamless bidirectional translation between Arabic and several major languages, including English and French. Leveraging state-of-the-art artificial intelligence, TranslatorAR is capable of handling large volumes of text with high accuracy and efficiency. The system utilizes cutting-edge natural language processing models to ensure precise translations and contextual relevance, making it a valuable tool for academic, professional, and personal use. By integrating sophisticated machine learning techniques, TranslatorAR provides a reliable solution for overcoming language barriers and enhancing cross-cultural communication.


```python
!pip install sacremoses
!pip install --upgrade translatorAR
```

    Requirement already satisfied: sacremoses in /usr/local/lib/python3.10/dist-packages (0.1.1)
    Requirement already satisfied: regex in /usr/local/lib/python3.10/dist-packages (from sacremoses) (2024.5.15)
    Requirement already satisfied: click in /usr/local/lib/python3.10/dist-packages (from sacremoses) (8.1.7)
    Requirement already satisfied: joblib in /usr/local/lib/python3.10/dist-packages (from sacremoses) (1.4.2)
    Requirement already satisfied: tqdm in /usr/local/lib/python3.10/dist-packages (from sacremoses) (4.66.4)
    Requirement already satisfied: translatorAR in /usr/local/lib/python3.10/dist-packages (0.2.1)
    Requirement already satisfied: transformers in /usr/local/lib/python3.10/dist-packages (from translatorAR) (4.42.4)
    Requirement already satisfied: pymupdf in /usr/local/lib/python3.10/dist-packages (from translatorAR) (1.24.9)
    Requirement already satisfied: tqdm in /usr/local/lib/python3.10/dist-packages (from translatorAR) (4.66.4)
    Requirement already satisfied: pdf2image in /usr/local/lib/python3.10/dist-packages (from translatorAR) (1.17.0)
    Requirement already satisfied: pytesseract in /usr/local/lib/python3.10/dist-packages (from translatorAR) (0.3.10)
    Requirement already satisfied: pillow in /usr/local/lib/python3.10/dist-packages (from translatorAR) (9.4.0)
    Requirement already satisfied: PyMuPDFb==1.24.9 in /usr/local/lib/python3.10/dist-packages (from pymupdf->translatorAR) (1.24.9)
    Requirement already satisfied: packaging>=21.3 in /usr/local/lib/python3.10/dist-packages (from pytesseract->translatorAR) (24.1)
    Requirement already satisfied: filelock in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (3.15.4)
    Requirement already satisfied: huggingface-hub<1.0,>=0.23.2 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (0.23.5)
    Requirement already satisfied: numpy<2.0,>=1.17 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (1.26.4)
    Requirement already satisfied: pyyaml>=5.1 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (6.0.1)
    Requirement already satisfied: regex!=2019.12.17 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (2024.5.15)
    Requirement already satisfied: requests in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (2.31.0)
    Requirement already satisfied: safetensors>=0.4.1 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (0.4.3)
    Requirement already satisfied: tokenizers<0.20,>=0.19 in /usr/local/lib/python3.10/dist-packages (from transformers->translatorAR) (0.19.1)
    Requirement already satisfied: fsspec>=2023.5.0 in /usr/local/lib/python3.10/dist-packages (from huggingface-hub<1.0,>=0.23.2->transformers->translatorAR) (2024.6.1)
    Requirement already satisfied: typing-extensions>=3.7.4.3 in /usr/local/lib/python3.10/dist-packages (from huggingface-hub<1.0,>=0.23.2->transformers->translatorAR) (4.12.2)
    Requirement already satisfied: charset-normalizer<4,>=2 in /usr/local/lib/python3.10/dist-packages (from requests->transformers->translatorAR) (3.3.2)
    Requirement already satisfied: idna<4,>=2.5 in /usr/local/lib/python3.10/dist-packages (from requests->transformers->translatorAR) (3.7)
    Requirement already satisfied: urllib3<3,>=1.21.1 in /usr/local/lib/python3.10/dist-packages (from requests->transformers->translatorAR) (2.0.7)
    Requirement already satisfied: certifi>=2017.4.17 in /usr/local/lib/python3.10/dist-packages (from requests->transformers->translatorAR) (2024.7.4)



```python
from translatorAR import TranslatorAR
```


```python
# Create an instance of the Translator class
translator = TranslatorAR()
```

    Initializing translation pipelines...


    /usr/local/lib/python3.10/dist-packages/huggingface_hub/utils/_token.py:89: UserWarning: 
    The secret `HF_TOKEN` does not exist in your Colab secrets.
    To authenticate with the Hugging Face Hub, create a token in your settings tab (https://huggingface.co/settings/tokens), set it as secret in your Google Colab and restart your session.
    You will be able to reuse this secret in all of your notebooks.
    Please note that authentication is recommended but still optional to access public models or datasets.
      warnings.warn(


    Initialization completed in 34.55 seconds.


## Demo 1 - Simple sentences


```python
# Example 1: Arabic to English
text_ar_en = "هذا المساق مقدم من Amin Boulouma."
translated_text_ar_en = translator.translate(text_ar_en, "ar", "en")
translator.print_translation(text_ar_en, translated_text_ar_en, "ar", "en")

# Example 2: English to Arabic
text_en_ar = "This course is produced by Amin Boulouma."
translated_text_en_ar = translator.translate(text_en_ar, "en", "ar")
translator.print_translation(text_en_ar, translated_text_en_ar, "en", "ar")

# Example 3: Arabic to French
text_ar_fr = "أهلاً وسهلاً بكم في هذا المساق."
translated_text_ar_fr = translator.translate(text_ar_fr, "ar", "fr")
translator.print_translation(text_ar_fr, translated_text_ar_fr, "ar", "fr")

# Example 4: French to Arabic
text_fr_ar = "Bienvenue dans ce cours."
translated_text_fr_ar = translator.translate(text_fr_ar, "fr", "ar")
translator.print_translation(text_fr_ar, translated_text_fr_ar, "fr", "ar")
```

    Translating: 100%|██████████| 1/1 [00:00<00:00,  1.12it/s]


    Translation completed in 0.90 seconds.
    --- Translation from ar to en ---
    Source Text (ar):
    هذا المساق مقدم من Amin Boulouma.
    
    Translated Text (en):
    This course is presented by Amin Boulouuma.
    
    Statistics:
      Source Text: 6 words, 33 characters, 1 sentences
      Translated Text: 7 words, 43 characters, 1 sentences


    Translating: 100%|██████████| 1/1 [00:00<00:00,  1.15it/s]


    Translation completed in 0.88 seconds.
    --- Translation from en to ar ---
    Source Text (en):
    This course is produced by Amin Boulouma.
    
    Translated Text (ar):
    وهذه الدورة هي من إنتاج أمين بولوما.
    
    Statistics:
      Source Text: 7 words, 41 characters, 1 sentences
      Translated Text: 7 words, 36 characters, 1 sentences


    Translating: 100%|██████████| 1/1 [00:00<00:00,  1.77it/s]


    Translation completed in 0.58 seconds.
    --- Translation from ar to fr ---
    Source Text (ar):
    أهلاً وسهلاً بكم في هذا المساق.
    
    Translated Text (fr):
    Bienvenue dans cette allée.
    
    Statistics:
      Source Text: 6 words, 31 characters, 1 sentences
      Translated Text: 4 words, 27 characters, 1 sentences


    Translating: 100%|██████████| 1/1 [00:00<00:00,  1.86it/s]

    Translation completed in 0.55 seconds.
    --- Translation from fr to ar ---
    Source Text (fr):
    Bienvenue dans ce cours.
    
    Translated Text (ar):
    مرحباً بكم في هذا الفصل.
    
    Statistics:
      Source Text: 4 words, 24 characters, 1 sentences
      Translated Text: 5 words, 24 characters, 1 sentences


    
# Demo 2 - Translating a PDF File


```python
PDF_FILE_PATH = "arabic-text.pdf"
```


```python
# Example 1.bis: Translate Arabic PDF to English
translator.print_pdf_translation_results(PDF_FILE_PATH, "ar", "en", 'translated_to_english.txt')
```

    Extracting text from pages: 100%|██████████| 5/5 [00:00<00:00, 65.15it/s]


    Text extraction completed in 0.12 seconds.


    Translating: 100%|██████████| 33/33 [03:23<00:00,  6.18s/it]

    Translation completed in 203.81 seconds.
    Text saved to file in 0.00 seconds.
    PDF extraction completed in 203.93 seconds.
    Total process time (extraction + translation) : 203.93 seconds.
    --- PDF Translation Results ---
    Extracted Text from PDF:
    اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 1 وزارة اﻟﻌﺪل اﻷﻣﺮﯾﻜﯿﺔ وزارة اﻟﺘﻌﻠﯿﻢ اﻷﻣﺮﯾﻜﯿﺔ ﻗﺴﻢ اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻣﻜﺘﺐ اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻣﻌﻠﻮﻣﺎت ﺣﻮل ﺣﻘﻮق ﺟﻤﯿﻊ اﻷطﻔﺎل ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس: ،أﺳﺌﻠﺔ وأﺟﻮﺑﺔ ﻟﻠﻮﻻﯾﺎت وا ﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ نيوبألاو ھﺪف ھﺬه اﻷﺳﺌﻠﺔ واﻷﺟﻮﺑﺔ ھﻮ ﻣﺴﺎﻋﺪة اﻟﻮﻻﯾﺎت و اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻋﻠﻰ اﻟﻮﻓﺎء ﺑﺎﻟﺘﺰاﻣﺎﺗﮭ ﺎ اﻟﻘﺎﻧﻮﻧﯿﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أن ﺳﯿﺎﺳﺎﺗﮭ ﺎ وﻣﻤﺎرﺳﺎﺗﮭ ﺎ ﺑﺸﺄن اﻟﺘﺴﺠﯿﻞ1 ﻓﻲ اﻟﻤﺪارس اﻟﻌﺎﻣﺔ ﻋﻠﻰ اﻟﻤﺴﺘﻮ ا ﯾﯿﻦ اﻻﺑﺘﺪاﺋﻲ واﻟﺜﺎﻧﻮي ﻻ ﺗﻤﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ ، وﻻ ﺗﻌﯿﻖ أو ﺗﺜﺒﻂ ﻣﺸﺎرﻛﺔ اﻟﻄﻼب ﻓﻲ ا ﻟ ﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪارس اﻻﺑﺘﺪاﺋﯿﺔ واﻟﺜﺎﻧﻮﯾﺔ ﻋﻠﻰ أﺳﺎس وﺿﻊ اﻟﮭﺠﺮة اﻟﻔﻌﻠﻲ واﻟﻤﺘﺼﻮﱠ ر ﻟﮭﻢ أو ﻵ ﺑﺎﺋﮭﻢ. وﺗﺸﺠﻊ ﻛﻞ ﻣﻦ وزارة اﻟﻌﺪل ووزارة اﻟﺘﻌﻠﯿﻢ اﻷﻣﺮﯾﻜﯿﺔ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ اﻟﺘﻨﻔﯿﺬ ﺑﺸﻜﻞ إ ﺳﺘﺒﺎﻗﻲ ﻟﺴﯿﺎﺳﺎت وﻣﻤﺎرﺳﺎت ﻣﺴﺎﻧﺪة ﻟ ﻠﺘﺴﺠﯿﻞ واﻟﺘﻲ ﺗﺨﻠﻖ ﺑﯿﺌﺔ ﺗﺮﺣﯿﺒﯿﺔ ﺑ ﺠﻤﯿﻊ اﻟﻄﻼب وﺷﺎﻣﻠﺔ. ﻟﮭﻢ 2 اﻟﺘﻮﺛﯿﻖ – س1. ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻻﺳﺘﻔﺴﺎر ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة أو اﻟﺠﻨﺴﯿﺔ ﻟﻠ ﻄﺎﻟﺐ أو اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ3 ﻛﻮﺳﯿﻠﺔ ﻹﺛﺒﺎت إﻗﺎﻣﺘﮫ ﻓﻲ اﻟﻤﻨﻄﻘﺔ؟ ج – 1. ﻛﻼ. ﻟﯿﺲ ﻟﻠﺠﻨﺴﯿﺔ ﻟ أو ﻮﺿﻊ اﻟﮭﺠﺮة ﻋﻼﻗﺔ ﺑﺈﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻓﻲ اﻟﻤﻨﻄﻘﺔ، واﻻﺳﺘﻔﺴﺎر ﻋﻦ ذﻟﻚ ﻓﻲ ﺳﯿﺎق إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻟﯿﺲ ﺿﺮورﯾًﺎ وﻗﺪ ﯾﺆدي إﻟﻰ ﺗﺜﺒ ﯿ ﻂ ﻋﺰﯾﻤﺔ اﻟﻄﺎﻟﺐ أو إﻋﺎﻗﺘﮫ ﻋﻦ ا ﻟﺘﺴﺠﯿﻞ. س – 2. ھﻞ ﯾُﻄﻠﺐ ﻣﻦ اﻟﻄﻼب ، ﻣﺎ ﻋﺪا اﻟﻄﻼب اﻟﻤﺸﺮدﯾﻦ ﺑﺤﺴﺐ ﻣﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻣﻦ ﻗﺒﻞ اﻟﻘﺎﻧﻮن اﻟﻔﺪراﻟﻲ، ﺑﯿﺎن اﻹﻗﺎﻣﺔ اﻟﺤﺎﻟﯿﺔ ﻓﻲ ﻣﻨﻄﻘﺔ ﻣﺎ ﻟ ﯿﺘﺴﻨﻰ ﻟﮭﻢ اﻟﺘﺴﺠﯿﻞ ﻓﻲ إﺣﺪى ﻣﺪارس اﻟﻤﻨﻄﻘﺔ؟ ج – 2. ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺔ أو اﻟﻤﻨﻄﻘﺔ إﺛﺒﺎت ﻣﺘﻄﻠﺒﺎت اﻹﻗﺎﻣﺔ اﻟﺤﻘﯿﻘﯿﺔ وﺑﺎﻟﺘﺎﻟﻲ ﯾﻤﻜﻦ أن ﺗﻄﻠﺐ ﻣﻦ ﺟﻤﯿﻊ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ ﺗﻘﺪﯾﻢ إﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﻣﺎ ﻋﺪا اﻟﻤﺸﺮدﯾﻦ ﻛﻤﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻓﻲ اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ رﻗﻢ 42 ، اﻟﺠﺰء11301 وﻣﺎ ﯾﻠﯿﮫ ،اﻟﺨﺎص ﺑﻤ ﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ، ﻣﺎﻛﱢﻨﻲ- ﯾﻨﺘﻮﭭ. س –. 3 ﻛﯿﻒ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ اﻟﻮﻓﺎء ﺑﺎﻟﺘﺰاﻣﺎﺗﮭﻢ ﻟﻠﺪﻻﻟﺔ ﻋﻠﻰ إﻗﺎﻣﺘﮭﻢ ﻓﻲ ﻣﻨﻄﻘﺔ اﻟﻤﺪرﺳﺔ؟ ج – 3. اﻷﻧﻈﻤﺔ اﻟﻤﺘﻌﻠﻘﺔ ﺑﺎﻻ ﺳﺘﻤﺎرات اﻟﻤﻤﻜﻦ اﺳﺘﺨﺪاﻣﮭﺎ ﻟﺘﻮﺛﯿﻖ اﻹﻗﺎﻣﺔ داﺧﻞ اﻟﻤﻨﻄﻘﺔ ﺗﺨﺘﻠﻒ ﺑﯿﻦ اﻟﻮﻻﯾﺎت. ﺗﻘﺒﻞ اﻟﻤﻨﺎطﻖ ﻋﺎدة وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻛ ﺪﻟﯿﻞ ﻋﻠﻰ ا ﻹﻗﺎﻣﺔ، ﻓﺎﺗﻮرة ھﺎﺗﻒ أو ﻓﺎﺗﻮرة ﻣﯿﺎه ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، وﺛﯿﻘﺔ رھﻦ ﻋﻘﺎري أو ﻋﻘﺪ إﯾﺠﺎر ، إﻓﺎدة ﺧﻄﯿﺔ ﻣﺸﻔﻮﻋﺔ ﺑﺎﻟﯿﻤﯿﻦ ﻣﻦ أﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو وﻟﻲ اﻷﻣﺮ ، وﺻﻮﻻت ﺑﺪﻓﻊ اﻹﯾﺠﺎر، ﻧﺴﺨﺔ ﻣﻦ ﺣﻮاﻟﺔ ﻣﺎﻟﯿﺔ ﻟﺪﻓﻊ اﻹﯾﺠﺎر، أو رﺳﺎﻟﺔ ﻣﻦ ﻣُﺴﺘﺨﺪِم أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ ﻣﻜﺘﻮﺑﺔ ﻋﻠﻰ ورق ﯾﺤ ﻤﻞ ﺗﺮوﯾﺴﺔ اﻟﺸﺮﻛﺔ. ﯾﺠﺐ اﻟﺴﻤﺎح ﻷﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو ﻟﻮﻟﻲ اﻷﻣﺮ إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﺑﺎﺳﺘﺨﺪام أي ﻣﻦ اﻟﻮﺳﺎﺋﻞ اﻟﺒﺪﯾﻠﺔ اﻟﻤﻨﺼﻮص ﻋﻠﯿﮭﺎ ﻓﻲ اﻟﻘﺎﻧﻮن اﻟﻤﺤﻠﻲ أو ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ. ﻻ ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺗﻄﺒﯿﻖ ﻗﻮاﻧﯿﻦ ﻣﺨﺘﻠﻔﺔ، أو ﺗﻄﺒﯿﻖ ﻧﻔﺲ اﻟﻘﻮاﻧﯿﻦ ﺑﻄﺮق ﻣﺨﺘﻠﻔﺔ ﻋﻠﻰ اﻷطﻔﺎل ﺑﻨﺎءً ﻋﻠﻰ 1 ﻷﻏﺮاض ھﺬا اﻟﺘﻮﺟﯿﮫ، ﻓﺈن اﻟﻤُﺼﻄﻠﺢ" اﻟﺘﺴﺠﯿﻞ" ﯾﻌﻨﻲ أﯾﻀًﺎ اﻟﺘﺴﺠﯿﻞ، اﻟﻘﺒﻮل ﻓﻲ اﻟﺠﺎﻣﻌﺔ، أو اﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ. 2 أُرﻓِﻘﺖ وﺛﯿﻘﺔ اﻷﺳﺌﻠﺔ واﻷﺟﻮﺑﺔ ھﺬه ﺑﺮﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ ﺣﻮل ﻣﻮﺿﻮع ﺣﻖ ﺟﻤﯿﻊ اﻷطﻔﺎل ﺑﺎﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪارس، اﻟﺼﺎدرة ﻓﻲ 6 /ﻣﺎﯾﻮ أﯾﺎر 2011. ﺗﻢ ﺗﺤﺪﯾﺚ ھﺬه اﻟﻮﺛﯿﻘﺔ ﻟﻼﺟﺎﺑﺔ ﻋﻦ أﺳﺌﻠﺔ إﺿﺎﻓﯿﺔ ﺗﻢ اﺳﺘﻼﻣﮭﺎ ﻣﻨﺬ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﺼﺎدرة ﻋﺎم 2011. 3 ﻷﻏﺮاض ھﺬا اﻟﺘﻮﺟﯿﮫ، ﯾﻌﻨﻲ اﻟﻤُﺼﻄﻠﺢ"اﻟﻮاﻟﺪي" أﯾﻀﺎ اﻟﻮﺻﻲ أو ﺷﺨﺼًﺎ ﻣﺴﺆوﻻ آﺧﺮ وﻓﻘًﺎ ﻟ ﻠﻘﺎﻧﻮن اﻟﻤﺤﻠﻲ أو ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ. [OCR-00072-AR] اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 2 أ ﺳﺎس ﻋِ ﺮﻗﮭﻢ أو ﻋِ ﺮق آﺑﺎﺋ ﮭﻢ اﻟﻔﻌﻠﻲ أو اﻟﻤﺘﺼﻮﱠر ، أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ أو ، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة، أو أي ﻋﻨﺼﺮ آﺧﺮ ﻏﯿﺮ ﺟﺎﺋﺰ. ﯾﺠﺐ ﻣﻌﺎﻣﻠﺔ ﺟﻤﯿﻊ اﻟﻄﻼب ﺑﺎﻟﺘﺴﺎوي. 4 ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ﻣﺮاﺟﻌﺔ ﻗﺎﺋﻤﺔ اﻟﻮﺛﺎﺋﻖ اﻟﺘﻲ ﯾﻤﻜﻦ أن ﯾﺘﻢ اﺳﺘﺨﺪاﻣﮭﺎ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أن أ ﯾﺔ وﺛﺎﺋﻖ ﻣﻄﻠﻮﺑﺔ ﻻ ﺗﻤﻨﻊ أو ﺗﻌﯿﻖ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ أي طﺎﻟﺐ ﻟ ﻠﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ إذا ﻛﺎن اﻟﻄﺎﻟﺐ أو أﺑﻮﯾﮫ أو أوﻟﯿﺎء أﻣﺮه ال نولمحي وﺛﺎﺋﻖ ﺛﺒﻮﺗﯿﺔ. ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، ﺑﯿﻨﻤﺎ ﯾﻤﻜﻦ أن ﯾﺸﻤﻞ اﺧﺘﯿﺎر اﻟﻤﻨﻄﻘﺔ اﻟ ﮭﻮﯾﺔ اﻟﺼﺎدرة ﻋﻦ اﻟﻮﻻﯾﺔ أو رﺧﺼﺔ اﻟﻘﯿﺎدة اﻟﺼﺎدرة ﻷﺣﺪ اﻷﺑﻮﯾﻦ أو ﻟﻮﻟﻲ اﻷﻣﺮ ﻣﻦ ﺿﻤﻦ وﺛﺎﺋﻖ أﺧﺮى ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﻻ ﯾﺠﻮز ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ طﻠﺐ وﺛﯿﻘﺔ ﻛﮭﺬه ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ أو ﻹﻏﺮاض أﺧﺮى ﺑﺤﯿﺚ ﯾﻤﻜﻦ ﻟﮭﺬا اﻟﻄﻠﺐ أن ﯾﻤﻨﻊ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ اﻟ ﻄﺎﻟﺐ اﻟﺬي ﻟﻢ ﯾﻜﻦ أﺑﻮ ه ا ﯾﺤﻤﻼن وﺛﺎﺋﻖ ﻟ ﻠﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ. س – 4. ھﻞ ﯾﻤﻜﻦ ﺎﻄﻟﻠ ﻟﺐ اﻟﺬي ﯾﻜﻮن طﻔﻼ ﻣُﺸﺮﱠدً ا ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ طﻔﻞ ﻣﺸﺮد ﻏﯿﺮ ﻣﻮﺛﻖ، إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻓﻲ ﻣﻨﻄﻘﺔ ﻟﻜﻲ ﯾُﺴﺠﻞ ﻓﻲ ﻣﺪرﺳﺔ اﻟﻤﻨﻄﻘﺔ؟ ج – 4. ﻛﻼ. ﺣﺘﻰ ﻟﻮ ﻛﺎن ﻟﺪى اﻟﻤﻨﻄﻘﺔ ﻣﺘﻄﻠﺒﺎت ﻣﺸﺮوﻋﺔ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﯾﺠﺐ ﻋﻠﯿﮭﺎ اﺳﺘﺜﻨﺎء ﺟﻤﯿ ﻊ اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺬﯾﻦ ﯾﻌﺘﺒﺮو ن ﻣﺸﺮدﯾﻦ وﻓﻘﺎ ﻟﻘﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ. ﻟﮭﺆﻻء اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺤﻖ ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ، ﺣﺘﻰ ﻟﻮ ﻟﻢ ﯾﺘ ﻤ ﻜﻦ أھﻠﮭﻢ ﻣﻦ إﺑﺮاز اﻟﻮﺛﺎﺋﻖ اﻟﺘﻲ ﺗﻜﻮن ﻣﻄﻠﻮﺑﺔ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ. ﯾﺤﺪد ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻤﺼﻄﻠﺢ"ا ﻷطﻔﺎل وا ﻟﺸﺒﺎن اﻟﻤﺸﺮدﯾﻦ" ﻛﻤﺎ ﯾﺸﻤﻞ، ﺟﺰﺋﯿًﺎ،" اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺬﯾﻦ ﯾﺸﺎرﻛﻮن أﺷﺨﺎﺻﺎ آﺧﺮﯾﻦ اﻟﺴﻜﻦ ﻧﺘﯿﺠﺔ ﺿﯿﺎع ﻣﻨﺎزﻟﮭﻢ، أو ﻧﺘﯿﺠﺔ ﻣﺼﺎﻋﺐ اﻗﺘﺼﺎدﯾﺔ، أو أﺳﺒﺎب ﻣﻤﺎﺛﻠﺔ؛ ﯾﻌﯿﺸﻮن ﻓﻲ ﻣﻮﺗﯿﻼت، ﻓﻨﺎدق، ﺣﺪاﺋﻖ اﻟﻌﺮﺑﺎت اﻟﻤﻘﻄﻮرة، أو أﻣﺎﻛﻦ اﻟﺘﺨﯿﯿﻢ ﻧﻈﺮًا ﻟﻌﺪم وﺟﻮد ﺳﻜﻦ ﺑﺪﯾﻞ ﻣﻨﺎﺳﺐ ؛ ﯾﻌﯿﺸﻮن ﻓﻲ ﻣﻼﺟﺊ طﻮارئ أو اﻧ ﺘﻘﺎﻟﯿﺔ؛ أو ﻣﺘﺮوﻛﯿﻦ ﻓﻲ اﻟﻤﺴﺘﺸﻔﯿﺎت؛ أو ﺑﺎﻧﺘﻈﺎر وﺿﻌﮭﻢ ﺗﺤﺖ اﻟﺮﻋﺎﯾﺔ اﻟﺒﺪﯾﻠﺔ،" وﻛﺬﻟﻚ أطﻔﺎل ﻋﻤﺎل اﻟﺰراﻋﺔ اﻟﻤﮭﺎﺟﺮﯾﻦ. ﺗﻮﺟﺪ ﻣﻌﻠﻮﻣﺎت إﺿﺎﻓﯿﺔ ﺗﺨﺘﺺ ﺑﻘﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ ﻋﻠﻰ اﻟﻤﻮﻗﻊ gov/programs/homeless/guidance. pdf www. ed.. س – 5. ﻛﯿﻒ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ إظﮭﺎر اﻟﺘﺰاﻣﮭﻢ ﺑﺸﺮوط اﻟﻤﺪرﺳﺔ ﻣﻦ ﺣﯿﺚ اﻟﻌﻤﺮ ؟ ج – 5. ﻛﻤﺎ ھﻮ اﻟﺤﺎل ﺑﺎﻟﻨﺴﺒﺔ ﻟﺸﺮوط اﻹﻗﺎﻣﺔ، ﺗﺨﺘﻠﻒ اﻟﻘﻮاﻧﯿﻦ ﺑﯿﻦ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺣﻮل أي ﻣﻦ اﻟﻮﺛﺎﺋﻖ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ إﺑﺮازھﺎ ﻟﯿﺒﺮھﻨﻮا ﻋﻠﻰ أﻧﮭﻢ ﯾﺴﺘﻮﻓﻮن ﺷﺮوط اﻟﻤﻨﻄﻘﺔ أو اﻟﻮﻻﯾﺔ اﻟﺘﻲ ﺗﺤﺪد اﻟﺤﺪ اﻷﻋﻠﻰ واﻷدﻧﻰ ﻣﻦ اﻟﻌﻤﺮ، وﺗﻘﺒﻞ اﻟﺴﻠﻄﺎت اﻟﻘﻀﺎﺋﯿﺔ ﻋﺎدة وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻟﮭﺬا اﻟﻐﺮض. ووﻓﻘﺎ ﻟﻠﻤﻨﻄﻘﺔ أو اﻟﻮﻻﯾﺔ، ﻓﯿﻤﻜﻦ ﻟﻮﺛﺎﺋﻖ ﺑﺪﯾﻠﺔ أن ﺗﺸﻤﻞ و ﻟﻜﻦ ﻻ ﺗﻘﺘﺼﺮ ﻋﻠﻰ: ﺷﮭﺎدة دﯾﻨﯿﺔ، ﺷﮭﺎدة ﻣﻦ ﻣﺴﺘﺸﻔﻰ أو طﺒﯿﺐ ﺗﺒﯿﻦ ﺗﺎرﯾﺦ اﻟﻮﻻدة؛ ﺗﺪوﯾﻨﺎ ﻓﻲ اﻟﻜﺘﺎب اﻟﻤﻘﺪس اﻟﺨﺎص ﺑﺎﻟﻌﺎﺋﻠﺔ؛ ﺳﺠﻞ ﺗﺒﻨﻲ؛ إﻓﺎدة ﺧﻄﯿﺔ ﻣﺸﻔﻮﻋﺔ ﺑﺎﻟ ﻦﯿﻤﯿ ﯾﺆدﯾﮭﺎ أﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو وﻟﻲ اﻷﻣﺮ ؛ ﺷﮭﺎدة ﻣﯿﻼد، ﺳﺠﻼت ﻣﺪرﺳﺔ ﺳﺎﺑﻘﺔ ﺗﻢ اﻟﺘﺤﻘﻖ ﻣﻨﮭﺎ أو أي وﺛﺎﺋﻖ أﺧﺮى ﯾﺠﯿﺰھﺎ اﻟﻘﺎﻧﻮن. ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﺗﻮﻋﯿﺔ اﻟﻮاﻟﺪﯾﻦ ﺑﺄﯾﺔ ﺑﺪاﺋﻞ ﺗﻜﻮن ﻣﻮﺟﻮدة ﻛﺠﺰء ﻣﻦ ﺟﮭﻮدھﻢ ﻟﻀﻤﺎن ﺑﯿﺌﺔ ﺗﺮﺣﯿﺒﯿﺔ وﺷﺎﻣﻠﺔ ﻟﺠﻤﯿﻊ اﻟﻄﻼب. طﻠﺒﺎت اﻟﻮﺛﺎﺋﻖ ﻛﺸﮭﺎدات اﻟﻤﯿﻼد ﯾﺠﺐ أن ﻻ ﺗﻤﻨﻊ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ أو ﺗﺜﺒﻂ ﻋﺰﯾﻤﺔ أي طﺎﻟﺐ ﻣﺴﺘﻘﺒﻠﻲ ﻣﻦ اﻟﺘﺴﺠﯿﻞ واﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟ ﻄﺎﻟﺐ اﻟﺬي ﻻ ﯾﺤﻤﻞ وﺛﺎﺋﻖ ﻗﺎﻧ ﻮﻧﯿﺔ أو اﻟﺬي ﻟﮫ أﺑﻮ ن ا ﻻ ﯾﺤﻤﻼن وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ ، أو طﻔﻞ أو ﺷﺎب ﻣﺸﺮد ﻛﻤﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻓﻲ ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ ) أﻧﻈﺮ – س 4.(، أﻋﻼه ﻻ ﯾﺠﻮز ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻨﻊ أو ﺗﺜﺒﯿﻂ ﻋﺰﯾﻤﺔ أي طﺎﻟﺐ ﻣﻦ اﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ ﻷن اﻟ ﻄﺎﻟﺐ ﻻ ﯾ ﻤﻠﻚ ﺷﮭﺎدة ﻣﯿﻼد أو ﻻ ﯾﺤﻤﻞ ﺳﺠﻼت ﺗﺸﯿﺮ إﻟﻰ وﻻدﺗﮫ ﻓﻲ ﻣﻜﺎن أﺟﻨﺒﻲ، ﻣﺜﻞ ﺷﮭﺎدة ﻣﯿﻼد أﺟﻨﺒﯿﺔ. وﻻ ﯾﺠﻮز أﯾﻀﺎ أن ﺗﻤﯿﺰ طﻠﺒﺎت اﻟﻮﺛﺎﺋﻖ، أو ﯾﻜﻮن ﻟﮭﺎ ﺗﺄﺛﯿﺮ اﻟﺘﻤﯿﯿﺰ، ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. ﯾﺠﺐ أن ﯾﻌﺎﻣﻞ ﺟﻤﯿﻊ اﻟﻄﻼب ﺑﺎﻟﺘﺴﺎوي أﺛﻨﺎء ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ. 4 ﯾﻤﻨﻊ اﻟﺘﺸﺮﯾﻊIV ﻓﻲ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎم 1964 ، واﻟﺬي وﺿﻊ ﻣﻮﺿﻊ اﻟﺘﻨﻔﯿﺬ ﻣﻦ ﻗﺒﻞ وزارة اﻟﻌﺪل، اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻦ اﺗﺨﺎذ إﺟﺮاءات ﺗﺤﺮم اﻟﻄﻼب ﻣﻦ اﻟﺤﻤﺎﯾﺔ اﻟﻤﺘﺴﺎوﯾﺔ اﻟﺘﻲ ﺗﻤﻨﺤﮭﺎ اﻟﻘﻮاﻧﯿﻦ. اﻟﺘﺸﺮﯾﻊ VI ﻓﻲ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎم1964 ، واﻟﺬي وﺿﻊ ﻣﻮﺿﻊ اﻟﺘﻨﻔﯿﺬ ﻣﻦ ﻗﺒﻞ وزارة اﻟﺘﻌﻠﯿﻢ، وﻣﻦ ﻗﺒﻞ وزارة اﻟﻌﺪل ﺑﻌﺪ إﺣﺎﻟﺘﮫ ﻣﻦ وﻛﺎﻟﺔ ﺗﻤﻮﯾﻞ ﻓﺪراﻟﯿﺔ ﻣﻦ ﺧﻼل اﻟﺘﺪﺧﻞ ﻓﻲ دﻋﻮى ﻗﻀﺎﺋﯿﺔ ﻗﺎﺋﻤﺔ، ﯾﻤﻨﻊ اﻟﺘﻤﯿﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِﺮق أو اﻟﻠﻮن أو اﻷﺻﻞ اﻟﻘﻮﻣﻲ. اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 3 ﻋﻼوة ﻋﻠﻰ ذﻟ ﻚ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ال نأ ﺗﺴﺘﺨﺪم ﺷﮭﺎدة ﻣﯿﻼد اﻟ ﻄﺎﻟﺐ أو وﺛﺎﺋﻖ أﺧﺮى ﯾ ﻘﺪﻣﮭﺎ أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ ﻛﺄﺳﺎس ﻟﻼﺳﺘﻔﺴﺎر ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﺎ ﻟ ﻄﺎﻟﺐ ، أو وﺿﻊ أﺑﻮﯾﮫ أو أﺑﻮﯾﮭﺎ، أو أي أﻓﺮاد آﺧﺮﯾﻦ ﻓﻲ اﻟﻌﺎﺋﻠﺔ. ﻣﻦ اﻟﻤﺤﺘﻤﻞ أن ﯾﻜﻮن ﻟﻄﻠﺒﺎت ﻛﮭﺬه ﺗﺄﺛﯿﺮ ﻻ ﯾﺸﺠﻊ ﻋﻠﻰ ﺗﺴﺠﯿﻞ ﻄﺎ اﻟ ﻟﺐ أو اﻟﻄﺎﻟﺒﺔ ﻋﻠﻰ أﺳﺎس وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﮫ أو ﺑﮭﺎ. س – 6. اذام ﻟﻮ ﻋﺎرض أﺣﺪ اﻷﺑﻮﯾﻦ ﺗﻘﺪﯾﻢ ﻧﺴﺨﺔ ﻣﻦ ﺷﮭﺎد اﻟ ﻤﯿﻼد اﻷﺟﻨﺒﯿﺔ ﻟﻺ ﺑﻦ أو اﻹﺑﻨﺔ، ﺧﻮﻓًﺎ ﻣﻦ أن ذﻟﻚ ﻗﺪ ﯾﺆدي إﻟﻰ أﺳﺌﻠﺔ ﺣﻮل وﺿﻊ اﻟﮭﺠﺮة ﺑﺎﻟﻨﺴﺒﺔ ﻟﻸﺑﻮﯾﻦ أو ﺟﻨﺴﯿﺔ اﻷﺑﻮﯾﻦ؟ – ج6. ﯾﺘﻢ ﺗﺸﺠﯿﻊ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻋﻠﻰ اﺗﺨﺎذ ﺧﻄﻮات اﺳﺘﺒﺎﻗﯿﺔ ﻟﺘﻮﻋﯿﺔ اﻵ ﺑﺎء ﺣﻮل ﺣﻘﻮق أطﻔﺎﻟﮭﻢ وﻹﻋﺎدة طﻤﺄﻧﺘﮭﻢ ﺑﺄن أطﻔﺎﻟﮭﻢ ﻣُﺮﺣﺐ ﺑﮭﻢ ﻓﻲ ﻣﻨﺎطﻘﮭﻢ اﻟﺘﻌﻠﯿﻤﯿﺔ. ﻓﻌﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، ﺗﺴﻤﺢ ﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ ﻋﺎدة ﻟﻠﻤﻨﻄﻘﺔ ﺑﺎﺳﺘﺨﺪام وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻹﺛﺒﺎت ﻋﻤﺮ اﻟﻄﻔﻞ. ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ا ﻹﻋﻼن ﺑﺄﻧﮭﺎ ﺳﺘﺴﺘﺨﺪم ﺷﮭﺎدة اﻟﻤﯿﻼد اﻷﺟﻨﺒﯿﺔ، ﺳﺠﻞ اﻟﻤﻌﻤﻮدﯾﺔ، أو وﺛﺎﺋﻖ ﺑﺪﯾﻠﺔ ﺑﻨﻔﺲ اﻟﻄﺮﯾﻘﺔ اﻟﺘﻲ ﺗﺴﺘﺨﺪ م ﻓﯿﮭﺎ ﺷﮭﺎدة اﻟﻤﯿﻼد اﻷﻣﺮﯾﻜﯿﺔ، ﺳﺠﻞ اﻟﻤﻌﻤﻮدﯾﺔ، أو وﺛﯿﻘﺔ ﺑﺪﯾﻠﺔ: ﻓﻘﻂ ﻹﺛﺒﺎت ﺮﻋﻤ اﻟﻄﻔﻞ. وﻛﻤﺎ ﺗﻢ ﺗﺄﻛﯿﺪه ﺳﺎﺑﻘﺎ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ﺗﻄﺒﯿﻖ ﻗﻮاﻧﯿﻨﮭﺎ وﻣﻌﺎﯾﯿﺮھﺎ ﻟﺘﻮﺛﯿﻖ اﻟﻌ ﻤﺮ أو اﻹﻗﺎﻣﺔ ﺑﻨﻔﺲ اﻟﻄﺮﯾﻘﺔ ﻟﻜﻞ ﺷﺨﺺ، ﺑﻐﺾ اﻟﻨﻈﺮ ﻋﻦ اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ ، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة. اﻟﻄﻔﻞ اﻟﻤﻮﻟﻮد ﻓﻲ ﺑﻠﺪ أﺟﻨﺒﻲ وﻏﯿﺮ ﻗﺎدر أو ﻏﯿﺮ راﻏﺐ ﻓﻲ ﺗﻘﺪﯾﻢ ﺷﮭﺎدة ﻣﯿﻼد، ﯾﺠﺐ أن ﺗﻜﻮن ﻟﮫ ﻧﻔﺲ اﻟﺨﯿﺎرات ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ و ﯾﺠﺐ أن ﻻ ﯾﻌﺎﻣﻞ ﺑﺄي ﺷﻜﻞ ﻣﺨﺘﻠ ﻒ ﻋﻦ طﻔﻞ أﻣﺮﯾﻜﻲ اﻟﺠﻨﺴﯿﺔ ﻻ ﯾﻤﻠﻚ أو ﺑﺸﻜﻞ آﺧﺮ ﻗﺪ ﻻ ﯾﺘﻤﻜﻦ ﻣﻦ إﺑﺮاز ﺷﮭﺎدة ﻣﯿﻼد. – س7. ﻓﻲ ﺿﻮء رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ، ھﻞ يغبني نا ﺗﻤﺘﻨﻊ اﻟﻤﻨﺎطﻖ ﻋﻦ طﻠﺐ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠ ﻄﺎﻟﺐ ؟ ج – 7. ﻻ ﺗﻤﻨﻊ اﻟﺤﻜﻮﻣﺔ اﻷﻣﺮﯾﻜﯿﺔ اﻟﻮﻻﯾﺎت أو اﻟﻤﻨﺎطﻖ ﻣﻦ ﺗﺤﺼﯿﻞ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠﺘﻼﻣﯿﺬ اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ أو اﻟﺤﺎﻟﯿﯿﻦ. ﻣﻊ ذﻟﻚ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ أن ﺗ ﻘﺮر ﻓﯿﻤﺎ إذا ﻛﺎن ﻟﺪﯾﮭ ﺎﺳﺒﺒ ﺎ ﻣﺴﻤﻮح ﺑﮫ اينوناق ﺤﺼﻠﻟ ﻮل ﻋﻠﻰ ھﺬه اﻟﻤﻌﻠﻮﻣﺎت. إذا اﺧﺘﺎر ت ﺗﺤﺼﯿﻞ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻋﻠﯿﮭ ﺎ اﺗﺨﺎذ ﺧﻄﻮات ﺗﻀﻤﻦ ﺧﺼﻮﺻﯿﺔ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ وأﻧ ﮭﺎ ﺗُﺨﺰﱠن ﺑﺸﻜﻞ آﻣﻦ. إﺿﺎﻓﺔ إﻟﻰ ذﻟﻚ، ﻋﻠﯿﮭ ﺎ اﺗﺒﺎع اﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ اﻟﺘﻲ ﺗﻨﻈﻢ اﺳﺘﺨﺪام ﺗﻠﻚ اﻟﻤﻌﻠﻮﻣﺎت. ﺑﻤﻮﺟﺐ ا ﻟﻘﻮاﻧﯿﻦ اﻟﻨﺎﻓﺬة، ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، إذا طﻠﺒﺖ ﻣﻨﻄﻘﺔ ﻣﺎ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻋﻠﯿﮭﺎ ﺗﺒﻠﯿﻎ اﻷﻓﺮاد أ ن اﻹﻓﺼﺎح ﻋﻨﮭﺎ ﯾﻜﻮن طﻮﻋﯿﺎ، وﯾﺠﺐ ﻋﻠﯿﮭﺎ ﺷﺮح اﻷﺳﺲ اﻟﺘﺸﺮﯾﻌﯿﺔ أو ﻏﯿﺮھﺎ وراء طﻠﺐ اﻷرﻗﺎم وﻛﯿﻒ ﺳﺘﻘﻮم اﻟﻤﻨﻄﻘﺔ ﺑﺎﺳﺘﺨﺪام اﻷرﻗﺎم. أﻧﻈﺮ ﻗﺎﻧﻮن اﻟﺨﺼﻮﺻﯿﺔ ﻟﻌﺎم 1974 ، اﻟﻨﺸﺮة إل. رﻗﻢ 579 - 93، اﻟﺠﺰء 5 و اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ رﻗﻢ 7 اﻟﺠﺰء552 ،(أ)ﻣﻼﺣﻈﺔ اﻟﻤﺘﻮﻓﺮ ﻋﻠﻰ: http://www. ssa. gov/OP_Home/comp2/F093-579. html. وﻛﻤﺎ ﺗﻮﺿﺤﮫ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ، ﻻ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ ﺣﺮﻣﺎن اﻟ ﻄﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ إذا اﺧﺘﺎر ھﻮ أو ھﻲ )أو أﺑﻮﯾﮭﻤ ﺎ أو أوﻟﯿﺎء أﻣﻮرھﻤ ﺎ ( ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ اﻟﺨﺎص ﺑﺎﻟ ﻄﺎﻟﺐ. 5 ﻟﺪى اﻟﻤﻨﺎطﻖ ﺑﺪاﺋﻞ ﻋﻦ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ. ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، إذا ﺳﻌﺖ اﻟﻤﻨﻄﻘﺔ ﻷن ﯾﺤﻤﻞ اﻟﻄﻼب أرﻗﺎم ھﻮﯾﺔ، ﻓﯿﻤﻜﻨﮭﺎ إﻋﻄﺎء ﻛﻞ طﺎﻟﺐ رﻗﻤﺎ ﯾﺘﻢ اﺧﺘﯿﺎره ﻋﺸﻮاﺋﯿﺎ. وﺑﮭﺬه اﻟﻄﺮﯾﻘﺔ، ﺗﺘﺠﻨﺐ اﻟﻮﻻﯾﺔ أو اﻟﻤﻨﻄﻘﺔ أي أﺛﺮ ﻂﺜﺒﻣُ ﻗﺪ ﯾﺘﺮﻛﮫ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻋﻠﻰ ﺗﺴﺠﯿﻞ اﻟﻄﻼب ﺑﺴﺐ اﻟﻌِﺮق أو اﻟﻠﻮن، اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. أو اﻟﺠﻨﺴﯿﺔ، أو وﺿﻊ اﻟﮭﺠﺮة اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﺘﻲ ﺗ ﻔﻀﻞ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ، ﻋﻠﯿﮭﺎ أن ﺗﻮﺿﺢ ﻓﻲ ﻛﺎﻓﺔ وﺛﺎﺋﻖ اﻟﺘﺴﺠﯿﻞ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻻﺳﺘﻤﺎرات، اﻟﻤﻮاﻗﻊ اﻹﻟﻜﺘﺮوﻧﯿﺔ، واﻻﺗﺼﺎﻻت ﻣﻊ أوﻟﯿﺎء اﻷﻣﻮر، أن ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠﻄﻔﻞ أﻣﺮ طﻮﻋﻲ، وأن اﺧﺘﯿﺎر ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻦ ﯾﻤﻨﻊ اﻟﻄﻔﻞ ﻣﻦ اﻟﺘﺴﺠﯿﻞ. س – 8 (. ﻛﯿﻒ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﺘﻔﺮﯾﻖ ﺑﯿﻦ )أ( اﻟﻤﻌﻠﻮﻣﺎت اﻟﺘﻲ ﻋﻠﯿﮭﺎ أو ﯾﺘﻮﺟﺐ ﻋﻠﯿﮭﺎ ﺗﺤﺼﯿﻠﮭﺎ، و )ب اﻟﻤﻌﻠﻮﻣﺎت اﻟﺘﻲ ﻻ ﯾﺠﻮز ﺗﺤﺼﯿﻠﮭﺎ ﻷن ذﻟﻚ ﯾﻤﻜﻦ أن ﯾﺜﺒﻂ اﻟﺘﺴﺠﯿﻞ أو اﻟﺪوام؟ ج – 8. ھﻨﺎك ﺣﺪ أدﻧﻰ ﻣﻦ اﻟﻤﻌﻠﻮﻣﺎت ﯾﻄﻠﺐ ﻋﺎدة ﻣﻦ اﻟﻤﻨﻄﻘﺔ ﺗﺤﺼﯿﻠﮫ ﺑﻤﻮﺟﺐ ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ ﻟﯿﺘﻤﻜﻦ أي طﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ ، ﻛﺈﺛﺒﺎت اﻟﻌﻤﺮ، ﺳﺠﻞ اﻟﺘﻄﻌﯿﻢ، واﻹﻗﺎﻣﺔ ﻓﻲ اﻟﻤﻨﻄﻘﺔ. ﻋﻠﻰ اﻟﻮﻻﯾﺔ واﻟﻤﻨﻄﻘﺔ اﻟﻌﻤﻞ وﻓﻘًﺎ ﻟﺪﺳﺘﻮر اﻟﻮﻻﯾﺎت اﻟﻤﺘﺤﺪة اﻷﻣﺮﯾﻜﯿﺔ 5 ﺑﺸﻜﻞ ﻣﻤﺎﺛﻞ، ﻻ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ إﻧﻜﺎر ﺣﻖ اﻟﻄﺎﻟﺐ ﻓﻲ اﻟﺘﺴﺠﯿﻞ إذا اﺧﺘﺎر أﺑﻮ ا ه أو أﺑﻮ ا ھﺎ ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ اﻟﺨﺎص ﺑﮫ أو ﺑﮭﺎ. واﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ وﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ اﻟﺴﺎرﯾﺔ ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟﺘﺰاﻣﮭﻢ ﺑﻌﺪم اﻟﺘﻤﯿﯿﺰ، أو ﺗﻨﻔﯿﺬ ﺳﯿﺎﺳﺎت ﻟﮭﺎ اﻷﺛﺮ ﻓﻲ اﻟﺘﻤﯿﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق، اﻟﻠﻮن، أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. وﺑﺎﻟﻘﯿﺎم ﺑﺬﻟﻚ اﻟﻌﻤﻞ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺗﻘﯿﯿﻢ ﺳﯿﺎﺳﺎﺗﮭ ﺎ ةيلاحلا ﻟﺘﺤﺪﯾﺪ ﻓﯿﻤﺎ إذا ﺗ ﺖﻛﺎﻧ ﻘﻮم ﺑﺄي ﻋﻤ ﻞ ﯾﻤﻜﻦ أن ﯾﺆدي، وﻟﻮ ﻋﻦ ﻏﯿﺮ ﻗﺼﺪ، إﻟﻰ إﺣﺒﺎط ﻋﻤﻠﯿﺔ ﺗﺴﺠﯿﻞ اﻹطﻔﺎل اﻟﺬﯾﻦ ﻻ ﯾﺤﻤﻠﻮن أي وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ، ﻛﻄﻠﺐ أوراق اﻟﮭﺠﺮة ، أو أرﻗﺎم اﻟﻀ ﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ أو رﺧﺼﺔ اﻟﻘﯿﺎدة أو ھﻮﯾﺔ ﺻﺎدرة ﻣﻦ اﻟﻮﻻﯾﺔ ﻟﻮﻟﻲ اﻷﻣﺮ. ﯾﺠﺐ ﺗﻐﯿﯿﺮ ﻣﺜﻞ ھﺬه اﻟﻤﻤﺎرﺳﺎت واﻟﺴﯿﺎﺳﺎت، ﻋﻨﺪ ﺗﺤﺪﯾﺪھﺎ، ﻹزاﻟﺔ أي أﺛﺮ ﯾﺤﺒﻂ ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ. س – 9. ﻷﺟﻞ ﺗﺠﻨﺐ إﺣﺒﺎط ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ ، ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ أي ﻣﻨﻄﻘﺔ ﺗﻌﻠﯿﻤﯿﺔ ﺗﺴﺠﯿﻞ اﻟﻄﻔﻞ اﻟﺬي ﯾﺄﺗﻲ إﻟﯿﮭﺎ وﺗﻄﻠﺐ اﻟﻮﺛﺎﺋﻖ ﻓﻲ وﻗﺖ ﻻﺣﻖ، ﺑﻌﺪ أن ﯾﺘﻢ ﺗﺴﺠﯿﻞ اﻟﻄﻔﻞ ﻓﯿﮭﺎ ؟ ج – 9. ﻛﻤﺎ ھﻮ ﻣﺪون أﻋﻼه، ﯾﻤﻜﻦ ﻟﻠﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﻄﻠﺐ ﻣﻦ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ ﻓﯿﮭﺎ أن ﯾﻘﺪﻣﻮا إﺛﺒﺎﺗﺎ ﻋﻠﻰ إﻗﺎﻣﺘﮭﻢ ﻓﻲ اﻟﻤﻨﻄﻘﺔ و/ أو ﺑ ﺎﻟﻌﻤﺮ ﻗﺒﻞ ﺗﺴﺠﯿﻠﮭﻢ ، ﻣﺎ ﻋﺪا إذا ﻛﺎن أي طﻔﻞ أو ﺷﺎب ﯾﻌﺘﺒﺮ ﻣﺸﺮدا ﺑﻤﻮﺟﺐ ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ. وﻣﻊ ذﻟﻚ، ﯾﺠﻮز أﯾﻀﺎ ﻟﻠﻤﻨﺎطﻖ أن ﺗﺨﺘﺎر اﻻﻧﺘﻈﺎر وﻋﺪم طﻠﺐ وﺛﺎﺋﻖ إﺿﺎﻓﯿﺔ ﯾﻤﻜﻦ أن ﺗﻜﻮن ﻣﻄﻠﻮﺑﺔ ﺑﻤﻮﺟﺐ ﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ أو اﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ ﻣﺜﻞ اﻟ ﺒﯿﺎﻧﺎت اﻟﺪﯾﻤﻮﻏﺮاﻓﯿﺔ ﻟﻠ ﻄﺎﻟﺐ ، إﻻ ﺑﻌﺪ أن ﯾﻜﻮن اﻟﻄﻼب ﻗﺪ ﺗﺴﺠﻠﻮا. وﺑﺎﺧﺘﯿﺎرھﺎ اﻻﻧﺘﻈﺎر ﻟﺘﺤﺼﯿﻞ ﻣﻌﻠﻮﻣﺎت إﺿﺎﻓﯿﺔ، ﻗﺪ ﺗﺆدي ﺗﻠﻚ اﻟﻤﻨﺎطﻖ إﻟﻰ ﺧﻠﻖ ﺟﻮ أﻛﺜﺮ ﺗﺮﺣﯿﺒﺎ وﺷﻤﻮﻻ ﻟﺠﻤﯿﻊ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ. طﻠﺒﺎت اﻟﻮﺛ ﺎﺋﻖ ﯾﺠﺐ أن ﻻ ﺗﻤﯿﺰ أو ﯾﻜﻮن ﻟﮭﺎ ﺗﺄﺛﯿﺮ ﻓﻲ اﻟﺘﻤﯿﯿﺰ، ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ.، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة س – 10. ﺑﻌﺪ ﺣﯿﺎزة اﻟﻤﻌﻠﻮﻣﺎت اﻟﺸﺨﺼﯿﺔ اﻟﺨﺎﺻﺔ ﺑﺎﻟﻄﺎﻟﺐ، ھﻞ ھﻨﺎك ظﺮوف ﯾﺠﻮز ﻟﻠﻤﺪرﺳﺔ ﻋﻨﺪھﺎ اﻟﻜﺸﻒ ﻋﻦ اﻟﻤﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﺘﻌﻠﯿﻢ ﺑﺪون ﻣﻮاﻓﻘﺔ اﻟﻄﺎﻟﺐ أو أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ؟ ج – 10. ھﻨﺎك ظﺮوف ﯾﺠﻮز ﻋﻨﺪھﺎ ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﻜﺸﻒ ﻋﻦ ﻣﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﻄﺎﻟﺐ، ﻟﻜﻦ ھﺬه اﻟﻈﺮوف ﻣﺤﺪودة وﻣﻦ ﻏﯿﺮ اﻟﻤﺤﺘﻤﻞ ﺗﻄﺒﯿﻘﮭﺎ ﻓﻲ أﻏﻠﺐ اﻟﺤﺎﻻت اﻟﺘﻲ ﺗﻮاﺟﮭﮭﺎ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ. ﯾﻤﻨﻊ ﻗﺎﻧﻮن ﺣﻘﻮق اﻟﺘﻌﻠﯿﻢ واﻟﺨﺼﻮﺻﯿﺔ ﻟﻠﻌﺎﺋﻼت ﻟﻌﺎم 1974 (FERPA) ﻋﻤﻮﻣًﺎ اﻟﻤﻨﺎطﻖ اﻟﺪراﺳﯿﺔ اﻟﺘﻲ ﺗﺤﺼﻞ ﻋﻠﻰ ﺗﻤﻮﯾﻞ ﻓﺪراﻟﻲ ﻣﻦ وزارة اﻟﺘﻌﻠﯿﻢ ﻣﻦ ﻛﺸﻒ ﻣﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﺘﻌﻠﯿﻢ اﻟﺨﺎﺻﺔ ﺑﺎﻟﻄﺎﻟﺐ واﻟﺘﻲ ﻟﻮﺣﺪھﺎ أو ﻣﺸﺘﺮﻛﺔ ﻣﻊ ﻣﻌﻠﻮﻣﺎت أﺧﺮى ﯾﻤﻜﻦ أن ﺗﺤﺪد ھﻮﯾﺔ اﻟﻄﺎﻟﺐ، ﺑﺪون ﻣﻮاﻓﻘﺔ ﺧﻄﯿﺔ ﻣﻦ أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ أو اﻟﻄﺎﻟﺐ )إذا ﻛﺎن ﻋﻤﺮه 18 ﻋﺎﻣﺎ أو رثكأ أو إذا ﻛﺎن ﯾﻨﺘﻈﻢ ﻓﻲ ﻣﺆﺳﺴﺔ ﺗﻌﻠﯿﻢ ﻋﺎﻟﻲ ﺑﻌﺪ اﻟﺪراﺳﺔ اﻟﺜﺎﻧﻮﯾﺔ(. اﻟﺮﺟﺎء اﻟﺮﺟﻮع إﻟ ﻰ اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ 20 اﻟﺠﺰء1232ج. ھﻨﺎﻟ ﻚ ﺑﻌﺾ اﻻﺳﺘﺜﻨﺎءات اﻟﻤﺤﺪودة ﻓﻲ ﻗﺎﻧﻮن ﺣﻘﻮق اﻟﺘﻌﻠﯿﻢ واﻟﺨﺼﻮﺻﯿﺔ ﻟﻠﻌﺎﺋﻼت ﻟﻌﺎم 1974 اﻟﻤﺘﻌﻠﻘﺔ ﺑﻄﻠﺐ وﺟﻮب اﻟﺤﺼﻮل ﻋﻠﻰ اﻟﻤﻮاﻓﻘﺔ اﻟﺨﻄﯿﺔ ﻗﺒﻞ اﻟﻜﺸﻒ ﻋﻦ ﻣﻌﻠﻮﻣﺎت ﺗﻌﺮﯾﻒ ﺷﺨﺼﯿﺔ ﻣﻦ ﺳﺠﻼت اﻟﻄﺎﻟﺐ اﻟﻤﺪرﺳﯿﺔ، أﻧﻈﺮ ﻗﺎﻧﻮن اﻟﻠﻮاﺋﺢ اﻟﻔﺪراﻟﯿﺔ 34 اﻟﺠﺰء99. 31 ، وﻛﺬﻟﻚ ظﺮوف ﻣﺤﺪودة وﻣﻌﺪودة ﯾُ ﻄﻠَ ﺐ ﻓﯿﮭﺎ وﻓﻘﺎ ﻟﻘﻮاﻧﯿﻦ اﻟﮭﺠﺮة اﻟﻔﺪراﻟﯿﺔ اﻟﺴﻤﺎح ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﺑﺘﻮﻓﯿﺮ ﻣﻌﻠﻮﻣﺎ ت ﻣﺤﺪدة ﻋﻦ ﺗﻠﻤﯿﺬ ﻟﻜﯿﺎن ﺣﻜﻮﻣﻲ آﺧﺮ ﻓﺪراﻟﻲ أو ﻣﺤﻠﻲ أو ﺗﺎﺑﻊ ﻟﻠﻮﻻﯾﺔ. واﺣﺪة ﻣﻦ ﺗﻠﻚ اﻟﻈﺮوف ﺗﺘﻤﺜﻞ ﻓﻲ ﺣﺎﻟﺔ إﺻﺪار ﺗﺄﺷﯿﺮة ﻟﻐﯿﺮ اﻟﻤﮭﺎﺟﺮﯾﻦ ﻷﺣﺪ اﻟﻄﻠﺒﺔ — واﻟﻤﺤﺎﻓﻈﺔ ﻋﻠﻰ وﺿﻊ ﻋﺪم اﻟﮭﺠﺮة ﻟﺬﻟﻚ اﻟﻄﺎﻟﺐ — ﻣﺸﺮوطًﺎ ﺑﺪوام اﻟﻄﺎﻟﺐ ﻓﻲ ﻣﺪرﺳﺔ ﻣﻌﯿﻨﺔ. ﯾﺮﺟﻰ ﻣﻼﺣﻈﺔ أﻧﮫ ﻓﻲ ﺗﻠﻚ اﻟﺤﺎﻟﺔ، ﺗﻜﻮن ﻟﺪى اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻌﻠﻮﻣﺎت ﻣﺴﺒﻘﺔ ﻋﻦ اﻟﻄﺎﻟﺐ واﻟﺘﻲ ﯾﻜﻮن اﻟﻄﺎﻟﺐ أو اﻟﻄﺎﻟﺒﺔ ﻗﺪ ﻗﺪﻣ ﺎ ھﺎ ﻟﻠﻤﺪرﺳﺔ ﺑﻐﺮض اﻟﺤﺼﻮل ﻋﻠﻰ اﻟﺘﺄﺷﯿﺮة اﻷﺳﺎﺳﯿﺔ، وﺑﻨﺎء ﻋﻠﯿﮫ ﻻ ﯾﻜﻮن ﻟﻠﻤﺪرﺳﺔ ﺳﺒﺐ ﻟﻠﻤﺒﺎدرة ﺑﻄﻠﺐ ﻣﻌﻠﻮﻣﺎت ﺣﻮل وﺿﻊ اﻟﮭﺠﺮة. س – 11. ﻛﯿﻒ ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺪراﺳﯿﺔ اﻟﺘﻮاﺻﻞ ﻣﻊ اﻷﺑﻮﯾﻦ يدودحملا اﻟﻤﻌﺮﻓﺔ ﺑﺎﻟﻠﻐﺔ اﻹﻧﻜﻠﯿﺰﯾﺔ ﺑﺸﺄن ﻣﺘﻄﻠﺒﺎت اﻟﺘﺴﺠﯿﻞ ؟ ج – 11. ﺑﺎﻟﻨﺴﺒﺔ ﻷﺑﻮﯾﻦ اﻟﻄﺎﻟﺐ يدودحملا اﻟﻤﻌﺮﻓﺔ ﺑ ﺎﻟﻠﻐﺔ اﻹﻧﻜﻠﯿﺰﯾﺔ نيذلاو ﯾﺴﻌﻮن ﺗﺴﺠﯿﻠﮫ ﺑﺎﻟﻤﺪرﺳﺔ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ أن ﺗﻮﺻﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ اﻟﻤﺘﻌﻠﻘﺔ ﺑ ﺎﻟﺘﺴﺠﯿﻞ ﺑﻄﺮﯾﻘﺔ ھﺎدﻓﺔ – ﻣﺜﻼ، ﺗﻘﻮم ﺑﺘﺮﺟﻤﺔ اﻟﻮﺛﯿﻘﺔ إﻟﻰ ﻟﻐﺎت ﻏﯿﺮ اﻹﻧﻜﻠﯿﺰﯾﺔ أن و ﺗﺘﻮﻓﺮ ﻟﺪﯾﮭﺎ وﺳﯿﻠﺔ ﻹﺟﺎﺑﺔ نيوبألا ىلع اﻷﺳﺌﻠﺔ – ﻛﻤﺎ ھﻮ ﻣُﺸﺘﺮط ﻋﻠﯿﮫ ﻓﻲ اﻟﺘﺸﺮﯾﻊ VI ﻣﻦ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎ م 1964 ، اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ42 اﻟﺠﺰء2000د ، وﻗﺎﻧﻮن ﻓﺮص اﻟﺘﻌﻠﯿﻢ اﻟﻤﺘﺴﺎوﯾﺔ، اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ 20 اﻟﺠﺰء1703. وإن ﺗﻮﻓﺮت، ﻓﯿﻤﻜﻦ أن ﺗﺸﺘﻤﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ ﻋﻠﻰ وﺳﺎﺋﻞ ﺑﺪﯾﻠﺔ ﻹﺛﺒﺎت ﻣﺘﻄﻠﺒﺎت اﻹﻗﺎﻣﺔ وﻋﻤﺮ اﻟﻄﺎﻟﺐ اﻟﺬي ﺗﺴﻤﺢ ﺑﮭ ﺎ اﻟﻮﻻﯾﺔ. إذا ﻗﺎﻣﺖ اﻟﻤﻨﻄﻘﺔ ﺑﻄﻠﺐ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻗﺪ ﺗﺸﺘﻤﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ ﻋﻠﻰ ﺣﻘﯿﻘﺔ أن اﻟﻤﻨﻄﻘﺔ ﻻ اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 4 ﺗ ﺴﺘﻄﯿﻊ ﺣﺮﻣﺎن أي طﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ إن اﺧﺘﺎر اﻟﻄﺎﻟﺐ أو اﻟﻄﺎﻟﺒﺔ )أو أﺑﻮﯾﮫ، أﺑﻮﯾﮭﺎ أو أوﻟﯿﺎء أﻣﺮھﻤ ﺎ ( ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ. ﺗﺪاﺑﯿﺮ ﻣﺴﺎﻧﺪة إﺿﺎﻓﯿﺔ ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺎت أو اﻟﻤﻨﺎطﻖ اﺗﺨﺎذھﺎ س – 12. ﻣﺎذا ﯾﻤﻜﻦ ﻟﻠﻤﺪارس ﻋﻤﻠﮫ ﺑﺸﻜﻞ اﺳﺘﺒﺎﻗﻲ ﻟﺘﻈﮭﺮ ﻟﻸﺑﻮﯾﻦ أن أطﻔﺎﻟﮭﻢ ﻣﺮﺣﺐ ﺑﮭﻢ، ﺑﻐﺾ اﻟﻨﻈﺮ ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﮭﻢ أو ﺟﻨﺴﯿﺘﮭﻢ؟ ج – 12. ﺗﺸﺠﻊ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﻋﻠﻰ ﻣﺮاﺟﻌﺔ ﺳﯿﺎﺳﺎت اﻟﺘﺴﺠﯿﻞ واﻟﻤﻤﺎرﺳﺎت ﺑﻌﻨﺎﯾﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أﻧﮭ ﺎ ﻣﺘﺴﺎوﻗ ﺔ ﻣ ﻊ اﻟﻘﺎﻧﻮن وﻟﯿﺲ ﻟﺪﯾﮭ ﺎ ﺗﺄﺛﯿﺮ ﯾﺜﺒﻂ اﺳﺘﻌﺪاد اﻷﺑﻮﯾﻦ ﻟ ﺘﺴﺠﯿﻞ أطﻔﺎﻟﮭﻢ. ﯾﺠﺐ ﺗﺼﯿﺢ ﺔ أﯾ ﻣﺸﺎﻛﻞ. إﺿﺎﻓﺔ إﻟﻰ ذﻟﻚ، ﺗﺸﺠﻊ وزارة اﻟﺘﻌﻠﯿﻢ ةيكيرمالا ووزارة اﻟﻌﺪل اﻟﻤﻨﺎطﻖ ﻋﻠﻰ أن ﺗﻜﻮن ﺳﺒّﺎﻗﺔ إﻟﻰ إﺑﻼغ اﻷﺑﻮﯾﻦ ﺑﺤﻘﮭﻤﺎ ﻓﻲ إرﺳﺎل أطﻔﺎﻟﮭﻤﺎ إﻟﻰ ﻣﺪرﺳﺔ ﻋﺎﻣﺔ. ﯾﻤﻜﻦ ﻟﻠﻤﻨﺎطﻖ، ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، أن ﺗﻘﻮم ﺑﺎﻟﺘﻮاﺻﻞ ﻣﻊ اﻟﻤﺠﺘﻤﻌﺎت ﻹﺑﻼغ اﻷھﺎﻟﻲ ﺑﺄن ﺟﻤﯿﻊ اﻟﻄﻠﺒﺔ اﻟﻤﻘﯿﻤﯿﻦ ﻓﻲ اﻟﻤﻨﻄﻘﺔ ﻣُ ﺮﺣﱠﺐٌ ﺑﮭﻢ ﻟﻠﺪوام ﻓﻲ ﻣﺪارس اﻟﻤﻨﻄﻘﺔ. – س13. ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ اﻟﻤﻨﺎطﻖ ﺗﻮﻓﯿﺮ اﻟﺘﺪرﯾﺐ ﻟﻤﻮظﻔﯿﮭﺎ ﺣﻮل ﻛﯿﻔﯿﺔ ﺗﺠﻨﺐ ﻣﺨﺎﻟﻔﺔ اﻟﻘﺎﻧﻮن ﻓﻲ ھﺬا اﻟﻤﺠﺎل؟ ج – 13. ﯾُﺸﺠﻊ ﺗﺪرﯾﺐ اﻟﻤﻮظﻔﯿﻦ ﻋﻠﻰ ﻣﺴﺘﻮى اﻟﻤﺪرﺳﺔ واﻟﻤﻨﻄﻘﺔ. ﻓﻲ اﻟﻨﮭﺎﯾﺔ ، ﺗﺘﺤﻤﻞ اﻟﻮﻻﯾﺔ واﻟﻤﻨﻄﻘﺔ اﻟﻤﺴﺆوﻟﯿﺔ اﻟﻘﺎﻧﻮﻧﯿﺔ ﻟﻀﻤﺎن ا ﻣﺘﺜﺎﻟﮭ ﺎ نوناقلاب اﻟﻔﺪراﻟﻲ. ﺗﺪرﯾﺐ اﻟﻤﻮظﻔﯿﻦ ﯾُﺴﮭﱢﻞ ﻋﻤﻠﯿﺔ اﻻﻣﺘﺜﺎل. س – 14. ﻣﺎ ھﻮ دور وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ (SEAs) ﻓﻲ ﺿﻤﺎن ﻋﺪم اﺳﺘﺒﻌﺎد اﻟﻄﻼب ﻣﻦ اﻟﻤﺪرﺳﺔ ﺑﺸﻜﻞ ﻏﯿﺮ ﺻﺤﯿﺢ؟ س – 14. اﻟﻤﻘﺼﻮد ﻣﻦ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﺼﺎدرة ﻓﻲ6 ﻣﺎﯾﻮ/ أﯾﺎر2011 ، واﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ واﻟﻤﻌﺎد إﺻﺪارھﺎ ﻓﻲ 8 ﻣﺎﯾﻮ/ أﯾﺎر2014، ھﻮ ﺗﺬﻛﯿﺮ ﻛﻞ ﻣﻦ اﻟﻤﻨﺎطﻖ واﻟﻮﻻﯾﺎت ﺑﺎﻟﺘﺰاﻣﺎﺗﮭ ﺎ ﺑﻤﻮﺟﺐ اﻟﻘﺎﻧﻮن اﻟﻔﺪراﻟﻲ. ﻛﻤﺴﺘﻔﯿﺪ ة ﻣﻦ اﻟﺘﻤﻮﯾﻞ اﻟﻔﺪراﻟﻲ، ﻓﺈن وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﻣﺴﺆوﻟﺔ ﻋﻦ ﻣﺮاﻗﺒﺔ اﻻﻣﺘﺜﺎل نيناوقب ﻋﺪم اﻟﺘﻤﯿﯿﺰ اﻟﻔﺪراﻟﯿﺔ. ﺣﯿﺚ أن اﻟﻘﻮاﻧﯿﻦ اﻟﻤﺘﻌﻠﻘﺔ ﺑ ﺎﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس، ﺑﻤﺎ ﻓﯿﮭﺎ ﻣﺘﻄﻠﺒﺎت إﺛﺒﺎت اﻟﻌﻤﺮ واﻹﻗﺎﻣﺔ ﺗﺨﺘﻠﻒ ﻣﻦ وﻻﯾﺔ إﻟﻰ إﺧﺮى، ھﺬا ﻣﺠﺎل ﺗﻜﻮن ﻓﯿﮫ ﺣﺎﺟﺔ ﻷن ﺗﻘﻮم وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﺑﺪ ور ﻗﯿﺎدي وذات أﺛﺮ ﻓﻌﺎل ﺑﺸﻜﻞ ﺧﺎص. ﺗﺸﺠﱠ ﻊ وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﻋﻠﻰ ﻣﺮاﺟﻌﺔ اﻟﻤﻤﺎرﺳﺎت واﻟﺴﯿﺎﺳﺎت اﻟﻘﺎﺋﻤﺔ وﻣﺴﺎﻋﺪة ﻣﻨ ﺎطﻘﮭﺎ ﻋﻠﻰ ﻓﮭﻢ أﻧﻮاع اﻟﻤﻤﺎرﺳﺎت اﻟﺘﻲ ﺳﺘﺘﻮاﻓﻖ ﻣﻊ ﻣﺘﻄﻠﺒﺎت اﻟﻮﻻﯾﺔ ﺑﺨﺼﻮص اﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس ﻣﻦ دون أن ﺗﺨﺎﻟﻒ ﻣﺘﻄﻠﺒﺎت ﻋﺪم اﻟﺘﻤﯿﯿﺰ اﻟﺪﺳﺘﻮرﯾﺔ واﻟﻔﺪراﻟﯿﺔ. وﺑﺸﻜﻞ ﻣﺤﺪد، ﯾﺠﺐ ﻋﻠﻰ وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ اﻟﻌﻤﻞ ﻋﻠﻰ اﻟﺘﺄﻛﺪ ﻣﻦ أن ﻣﻤﺎرﺳﺎت اﻟﺘﺴﺠﯿﻞ اﻟﻤﺘﺒﻌﺔ ﻓﻲ ﻣﻨﺎطﻘﮭﺎ اﻟﺘﻌﻠﯿﻤﯿ ﺔ ﻻ ﺗﻌﯿﻖ أو ﺗﻤﻨﻊ اﻟﻄﻠﺒﺔ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ ﻋﻦ اﻟﻤﺪرﺳﺔ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟ ﻄﻼب أو آﺑﺎ ؤ ھﻢ اﻟﺬﯾﻦ ﻻ ﯾﺤﻤﻠﻮن وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ. اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 5
    
    Translated Text saved to 'translated_to_english.txt':
    The Ministry of Justice, the American Ministry of Education, the Urban Rights Department, the Urban Rights Office, has information on the rights of all children to school registration: questions and answers to state and state education areas, and to the New Palao areas. These questions and answers are aimed at helping state and learning areas to fulfil their obligations under the law to ensure that their laws and practices on registration in public schools at the primary and secondary levels do not discriminate on the basis of race, colour or national origin. The Ministry of Justice and the Ministry of Education encourage the registration of primary and secondary schools on the basis of the actual and perceived cheerleading status of students or the lack thereof. The Ministry of Justice and the Ministry of Education encourage American state and exile zones in a manner that will remain in place for the registrations and practices in support of the registrations that create a welcome and comprehensive mass of students. They are 2 totems S1. Does the region have to learn about the status of the jar or gender of the student or father or guardian of the order 3 as a means of proving her residence in the region? c. 1. No. for the sex of L. O. The migration has a relationship with proof of residence in the area, and the inquiry into this is in the context of proof of residence for a necessary reason, which may lead to proof of the student &apos; s determination or obstruction of registration. (c) Regulations on possible vehicles to be used in order to establish the identity of residents within the area are different in terms of state. Areas usually accept various documents such as Delilah to establish, for example, a telephone bill or a bill of funds for the use of a mortgage or a lease contract, a line statement accompanied by a parent or guardian, a receipt for payment of rent, A copy of a money transfer to pay rent, or a letter from an employee of a parent or guardian written on the company's bill of credit. One parent or guardian must be allowed to prove residence using any of the primitive means provided for in domestic law or state law. This document has been updated to answer additional questions received since the 2011 letter from the 2011 letter"Dear children's group" for the purposes of this directive. For the purpose of this direction, the term"parents" means a guardian or other responsible person in accordance with the local law or state law. [OCR-0072-AR] revised version of Mao/Aar 2014 2a palp palp or deed of de facto or perceived parentage, colour, national origin, gender or immigration status, or any element of race. The list of documents that you can use to prove residence must be reviewed in order to ensure that the identity of the documents required does not unduly prevent or bind any student for a period at school if the student or his father or his first guardian is a student or parent, or if the person is the guardian of his or her identity documents. For example, Spiel, the choice of the area of competence, or the licence to command a parent or guardian, may include a request for proof of residence. For other purposes, this request could unduly prevent a student who was not a documented homeless child, including a documented homeless child, from proving his residence in an area to be registered at the school in the area? c. No. Even if the area has legitimate requirements for proof of residence, the exclusion of the total number of children and young people should be considered homeless under the McNee-Vanto Federal Act to assist displaced persons. In school, even if I were not, they were to produce documents that would be required to prove residence. The McKinney-Vinto Act defines the term"wha children of homeless youth" as it includes, in part,"children and young people who share housing in order to create their own homes, or economic difficulties, or similar reasons; live in motels, hotels, trailer gardens, or spectacles, given the lack of adequate housing; live in emergency shelters or transfer; be left behind in hospitals; or wait for them to be placed under primitive care," as well as children of a family. There is additional information on the McKinney-Vinto Act to assist displaced persons on the website gov/programs/homeless/guidance. pdf www. ed. o. How can students demonstrate compliance with school conditions of age? c. 5. e. As with residency requirements, state and district laws differ about which documents can be cited to demonstrate that they meet the conditions of the area or state that determines the upper and lower age limit, and judicial authorities usually accept different documents for that purpose. Documents in the family's Bible could include, but are not limited to: Shahada Dinayah, a martyr from a hospital or a doctor whose birth has been verified or any other documents that have been passed by the law; an adoption record; a line statement accompanied by a parent or guardian; and a birth certificate, a previous school records verified or any other documents that have been obtained by the law. At the core of my future registration and attendance at school, including a student who does not have documents for the San and Niya or who has no legal documents, or a child or a homeless young person as provided for in the McKinley-Vanto Federal Act to assist displaced persons (see S. 4). above, the teaching area cannot prevent or discourage any student from attending school because the student does not own a birth certificate or does not have records of his birth in a foreign place, such as a foreign birth certificate. The general population of students must be treated equally during the registration process. 4 is the prohibition of article IV of the Urban Rights Act of 1964, which was put into effect by the Ministry of Justice, the learning area, from taking actions that deprive students of the equal protection accorded to them by the laws. Article VI of the Urban Rights Act of 1964, which was put in place by the Ministry of Education, and by the Ministry of Justice after its transfer from the Federal Finance Agency by intervening in an existing lawsuit, prevents the acquisition of equipment on the basis of race. In addition, K, the NA region is required to use the student's birth certificate or other documents submitted by a parent or guardian as a basis for enquiring about the student's grocery position, or the status of his or her parents, or any other members of the family. It is likely that they will be making demands such as these effects that they do not encourage the registration of the pulp or the demand on the basis of the cheek position of their cheer position or of their cheek. For example, the state laws usually allow the region to use different documents to prove the age of the child. The region must declare that it will use the testimony of the foreign child, the baptism record, or documents with the same means as the birth of the American child, the baptism record, or the identity of the material, only to prove that it's true that it's true that it's not true that it's true. A child born in a foreign country and a young person who is able or willing to present a birth certificate, must have the same options in school registration and must not be treated in any way as a child of an American sex worker who does not own or otherwise may not be able to produce a birth certificate. The government does not prevent American states or regions from obtaining the social security number for future or current students. However, states and learning areas must decide whether they are allowed to do so. For example, if a region requests social security figures, it should inform individuals about the fact that they are voluntary, and must explain the constitutional or other grounds for requesting numbers and how the region will use the figures. See the Private Law of 1974, Bulletin L. 579-93, part 5, and American Law No. 7, part 552, (a) Note available at http://www. ssa. gov/OP_Home/comp2/F093-579. html. As the letter of the Dazzle, the region cannot deny a student registration if he chooses to do it or to cheer him or her parents. For example, if the region seeks to hold student numbers and numbers, it can give each student a number that has been selected randomly. In this way, the state or region avoids any impact that may be left on the demand for social security figures on the registration of students by race or colour, national origin. The choice of not providing a social security number will not prevent the child from registering. C. 8 (e. g. the area can teach about the quality of the child's social security number by (a) the information on which or when the social security number must be obtained, and (b) the information that cannot be collected because it can discourage registration or attendance? c. 8. There is usually a minimum requirement for the area to be collected under the state law in order for any student to be able to register, such as proof of age, registration record, and stay. In accordance with the Constitution of the United States of America, the region cannot learn to deny the student &apos; s right to register if Abu Ah &apos; a or Abu &apos; ah choose not to provide their social security number. The federal laws and the state &apos; s laws, including their obligation not to have access to the equipment, or to carry out the impact on the equipment based on slavery, colour, or national origin. In order to prevent the disruption of the registration of children who are not in possession of any legal documents, such as the application for groove papers, social credit numbers, a licence to purchase credit, or an instrument issued by the State of the Crown, it is necessary to use such practices and policies, when they are challenged, to remove any trace of the frustration of the registration process. C9. In order to avoid the frustration of the registration process, any area of learning the registration of the child who has come to her or her request for documentation at a later date must, after the registration of the child has been completed? As listed above, if any child or young person is considered homeless under McKinney-Vanto's federal law to assist displaced persons, however, it is possible for the regions to choose to wait and not to request additional documents that may be required under the state or federal laws such as the student's demography, except after the students have been registered. There are circumstances in which a student may disclose information from the student's records when the information is disclosed without the consent of the student or a parent or guardian? c. 10. There are circumstances in which the learning area may disclose information from the student's records, but these conditions are limited and likely to be applied in most of the students' records. The Education and Special Rights of Families Act 1974 (FERPA) generally prohibits the study areas that obtain federal finance from the Ministry of Education from disclosing information from the student's own educational records, which alone or in association with other information may determine the student's identity, without the written consent of a parent, guardian or student (if he or she is 18 years of age or he or she is in a higher education institution after the second study). Please refer to the American Act 20 Part 1232c. The limited exceptions in the Education and Family Rights Act 1974 relating to the request for written consent before identifying a person from a student's records are disclosed, see the Federal Regulations Act 34 Part 99. 31, as well as limited and limited circumstances which, according to the provisions of the federal jar, allow the teaching area to provide specific knowledge of the student's achievement of another federal, local or state government entity. Please note that, in that case, the region has advance information about the student who is the student or student who has submitted him or her to the school for the purpose of obtaining basic evidence, and based on the fact that the school does not have a reason to initiate a request for information on the status of the horn. C. 11. For the student's parents, contact with the parent is required in the study area to convey knowledge of the English language about the requirements of registration? C. 11. For the student's father, he or she has knowledge of the English language Nizlaw. For example, in Section VI of the Civil Rights Act 1964, American Law 42, Part 2000d, and the Equal Learning Opportunities Act, American Law 20, Part 1703. If available, basic information can include alternative means to prove the student's residency requirements and the student's age, which allow for a student's life. If the region requests the social security number, the basic and cheerful information may include the fact that the area does not have the revised formula in Shihar Mao/Aiar 2014 4 T will be able to deny any student registration if the student or student chooses (or father), father or guardian (not to provide the social security number). In addition, the Ministry of Education encourages regions to be proactive in informing parents of their right to send their children to a public school. For example, regions can communicate with communities to inform communities that the majority of students in the region are welcome to attend school. In the meantime, the state and the area responsible for ensuring compliance with the law are responsible for ensuring that students are not excluded from school in a healthy manner? x. 14. The purpose of the commitment letter issued on 6 May 2011, revised and reissued on 8 May 2011, is to ensure that students are not excluded from school. x. 14. As a source of federal funding, state education agencies are responsible for monitoring compliance with the obligation not to develop federal legislation. The laws relating to school registration, which include the requirements for proof of age and residence, are different from one area to another. Specifically, state education agencies are required to ensure that registration practices in these areas do not unduly discourage or prevent students from school, including students or parents whose minds do not carry documents of law. The revised version of Mao/Aar 2014 5
    
    Statistics:
      Extracted Text: 2913 words, 16783 characters, 114 sentences
      Translated Text: 2457 words, 14426 characters, 102 sentences


    



```python
# Example 2.bis: Translate Arabic PDF to French
translator.print_pdf_translation_results(PDF_FILE_PATH, "ar", "fr", 'translated_to_french.txt')
```

    Extracting text from pages: 100%|██████████| 5/5 [00:00<00:00, 110.66it/s]


    Text extraction completed in 0.05 seconds.


    Translating: 100%|██████████| 33/33 [05:12<00:00,  9.48s/it]

    Translation completed in 312.70 seconds.
    Text saved to file in 0.01 seconds.
    PDF extraction completed in 312.77 seconds.
    Total process time (extraction + translation) : 312.77 seconds.
    --- PDF Translation Results ---
    Extracted Text from PDF:
    اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 1 وزارة اﻟﻌﺪل اﻷﻣﺮﯾﻜﯿﺔ وزارة اﻟﺘﻌﻠﯿﻢ اﻷﻣﺮﯾﻜﯿﺔ ﻗﺴﻢ اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻣﻜﺘﺐ اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻣﻌﻠﻮﻣﺎت ﺣﻮل ﺣﻘﻮق ﺟﻤﯿﻊ اﻷطﻔﺎل ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس: ،أﺳﺌﻠﺔ وأﺟﻮﺑﺔ ﻟﻠﻮﻻﯾﺎت وا ﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ نيوبألاو ھﺪف ھﺬه اﻷﺳﺌﻠﺔ واﻷﺟﻮﺑﺔ ھﻮ ﻣﺴﺎﻋﺪة اﻟﻮﻻﯾﺎت و اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻋﻠﻰ اﻟﻮﻓﺎء ﺑﺎﻟﺘﺰاﻣﺎﺗﮭ ﺎ اﻟﻘﺎﻧﻮﻧﯿﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أن ﺳﯿﺎﺳﺎﺗﮭ ﺎ وﻣﻤﺎرﺳﺎﺗﮭ ﺎ ﺑﺸﺄن اﻟﺘﺴﺠﯿﻞ1 ﻓﻲ اﻟﻤﺪارس اﻟﻌﺎﻣﺔ ﻋﻠﻰ اﻟﻤﺴﺘﻮ ا ﯾﯿﻦ اﻻﺑﺘﺪاﺋﻲ واﻟﺜﺎﻧﻮي ﻻ ﺗﻤﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ ، وﻻ ﺗﻌﯿﻖ أو ﺗﺜﺒﻂ ﻣﺸﺎرﻛﺔ اﻟﻄﻼب ﻓﻲ ا ﻟ ﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪارس اﻻﺑﺘﺪاﺋﯿﺔ واﻟﺜﺎﻧﻮﯾﺔ ﻋﻠﻰ أﺳﺎس وﺿﻊ اﻟﮭﺠﺮة اﻟﻔﻌﻠﻲ واﻟﻤﺘﺼﻮﱠ ر ﻟﮭﻢ أو ﻵ ﺑﺎﺋﮭﻢ. وﺗﺸﺠﻊ ﻛﻞ ﻣﻦ وزارة اﻟﻌﺪل ووزارة اﻟﺘﻌﻠﯿﻢ اﻷﻣﺮﯾﻜﯿﺔ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ اﻟﺘﻨﻔﯿﺬ ﺑﺸﻜﻞ إ ﺳﺘﺒﺎﻗﻲ ﻟﺴﯿﺎﺳﺎت وﻣﻤﺎرﺳﺎت ﻣﺴﺎﻧﺪة ﻟ ﻠﺘﺴﺠﯿﻞ واﻟﺘﻲ ﺗﺨﻠﻖ ﺑﯿﺌﺔ ﺗﺮﺣﯿﺒﯿﺔ ﺑ ﺠﻤﯿﻊ اﻟﻄﻼب وﺷﺎﻣﻠﺔ. ﻟﮭﻢ 2 اﻟﺘﻮﺛﯿﻖ – س1. ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻻﺳﺘﻔﺴﺎر ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة أو اﻟﺠﻨﺴﯿﺔ ﻟﻠ ﻄﺎﻟﺐ أو اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ3 ﻛﻮﺳﯿﻠﺔ ﻹﺛﺒﺎت إﻗﺎﻣﺘﮫ ﻓﻲ اﻟﻤﻨﻄﻘﺔ؟ ج – 1. ﻛﻼ. ﻟﯿﺲ ﻟﻠﺠﻨﺴﯿﺔ ﻟ أو ﻮﺿﻊ اﻟﮭﺠﺮة ﻋﻼﻗﺔ ﺑﺈﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻓﻲ اﻟﻤﻨﻄﻘﺔ، واﻻﺳﺘﻔﺴﺎر ﻋﻦ ذﻟﻚ ﻓﻲ ﺳﯿﺎق إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻟﯿﺲ ﺿﺮورﯾًﺎ وﻗﺪ ﯾﺆدي إﻟﻰ ﺗﺜﺒ ﯿ ﻂ ﻋﺰﯾﻤﺔ اﻟﻄﺎﻟﺐ أو إﻋﺎﻗﺘﮫ ﻋﻦ ا ﻟﺘﺴﺠﯿﻞ. س – 2. ھﻞ ﯾُﻄﻠﺐ ﻣﻦ اﻟﻄﻼب ، ﻣﺎ ﻋﺪا اﻟﻄﻼب اﻟﻤﺸﺮدﯾﻦ ﺑﺤﺴﺐ ﻣﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻣﻦ ﻗﺒﻞ اﻟﻘﺎﻧﻮن اﻟﻔﺪراﻟﻲ، ﺑﯿﺎن اﻹﻗﺎﻣﺔ اﻟﺤﺎﻟﯿﺔ ﻓﻲ ﻣﻨﻄﻘﺔ ﻣﺎ ﻟ ﯿﺘﺴﻨﻰ ﻟﮭﻢ اﻟﺘﺴﺠﯿﻞ ﻓﻲ إﺣﺪى ﻣﺪارس اﻟﻤﻨﻄﻘﺔ؟ ج – 2. ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺔ أو اﻟﻤﻨﻄﻘﺔ إﺛﺒﺎت ﻣﺘﻄﻠﺒﺎت اﻹﻗﺎﻣﺔ اﻟﺤﻘﯿﻘﯿﺔ وﺑﺎﻟﺘﺎﻟﻲ ﯾﻤﻜﻦ أن ﺗﻄﻠﺐ ﻣﻦ ﺟﻤﯿﻊ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ ﺗﻘﺪﯾﻢ إﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﻣﺎ ﻋﺪا اﻟﻤﺸﺮدﯾﻦ ﻛﻤﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻓﻲ اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ رﻗﻢ 42 ، اﻟﺠﺰء11301 وﻣﺎ ﯾﻠﯿﮫ ،اﻟﺨﺎص ﺑﻤ ﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ، ﻣﺎﻛﱢﻨﻲ- ﯾﻨﺘﻮﭭ. س –. 3 ﻛﯿﻒ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ اﻟﻮﻓﺎء ﺑﺎﻟﺘﺰاﻣﺎﺗﮭﻢ ﻟﻠﺪﻻﻟﺔ ﻋﻠﻰ إﻗﺎﻣﺘﮭﻢ ﻓﻲ ﻣﻨﻄﻘﺔ اﻟﻤﺪرﺳﺔ؟ ج – 3. اﻷﻧﻈﻤﺔ اﻟﻤﺘﻌﻠﻘﺔ ﺑﺎﻻ ﺳﺘﻤﺎرات اﻟﻤﻤﻜﻦ اﺳﺘﺨﺪاﻣﮭﺎ ﻟﺘﻮﺛﯿﻖ اﻹﻗﺎﻣﺔ داﺧﻞ اﻟﻤﻨﻄﻘﺔ ﺗﺨﺘﻠﻒ ﺑﯿﻦ اﻟﻮﻻﯾﺎت. ﺗﻘﺒﻞ اﻟﻤﻨﺎطﻖ ﻋﺎدة وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻛ ﺪﻟﯿﻞ ﻋﻠﻰ ا ﻹﻗﺎﻣﺔ، ﻓﺎﺗﻮرة ھﺎﺗﻒ أو ﻓﺎﺗﻮرة ﻣﯿﺎه ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، وﺛﯿﻘﺔ رھﻦ ﻋﻘﺎري أو ﻋﻘﺪ إﯾﺠﺎر ، إﻓﺎدة ﺧﻄﯿﺔ ﻣﺸﻔﻮﻋﺔ ﺑﺎﻟﯿﻤﯿﻦ ﻣﻦ أﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو وﻟﻲ اﻷﻣﺮ ، وﺻﻮﻻت ﺑﺪﻓﻊ اﻹﯾﺠﺎر، ﻧﺴﺨﺔ ﻣﻦ ﺣﻮاﻟﺔ ﻣﺎﻟﯿﺔ ﻟﺪﻓﻊ اﻹﯾﺠﺎر، أو رﺳﺎﻟﺔ ﻣﻦ ﻣُﺴﺘﺨﺪِم أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ ﻣﻜﺘﻮﺑﺔ ﻋﻠﻰ ورق ﯾﺤ ﻤﻞ ﺗﺮوﯾﺴﺔ اﻟﺸﺮﻛﺔ. ﯾﺠﺐ اﻟﺴﻤﺎح ﻷﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو ﻟﻮﻟﻲ اﻷﻣﺮ إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﺑﺎﺳﺘﺨﺪام أي ﻣﻦ اﻟﻮﺳﺎﺋﻞ اﻟﺒﺪﯾﻠﺔ اﻟﻤﻨﺼﻮص ﻋﻠﯿﮭﺎ ﻓﻲ اﻟﻘﺎﻧﻮن اﻟﻤﺤﻠﻲ أو ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ. ﻻ ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺗﻄﺒﯿﻖ ﻗﻮاﻧﯿﻦ ﻣﺨﺘﻠﻔﺔ، أو ﺗﻄﺒﯿﻖ ﻧﻔﺲ اﻟﻘﻮاﻧﯿﻦ ﺑﻄﺮق ﻣﺨﺘﻠﻔﺔ ﻋﻠﻰ اﻷطﻔﺎل ﺑﻨﺎءً ﻋﻠﻰ 1 ﻷﻏﺮاض ھﺬا اﻟﺘﻮﺟﯿﮫ، ﻓﺈن اﻟﻤُﺼﻄﻠﺢ" اﻟﺘﺴﺠﯿﻞ" ﯾﻌﻨﻲ أﯾﻀًﺎ اﻟﺘﺴﺠﯿﻞ، اﻟﻘﺒﻮل ﻓﻲ اﻟﺠﺎﻣﻌﺔ، أو اﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ. 2 أُرﻓِﻘﺖ وﺛﯿﻘﺔ اﻷﺳﺌﻠﺔ واﻷﺟﻮﺑﺔ ھﺬه ﺑﺮﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ ﺣﻮل ﻣﻮﺿﻮع ﺣﻖ ﺟﻤﯿﻊ اﻷطﻔﺎل ﺑﺎﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪارس، اﻟﺼﺎدرة ﻓﻲ 6 /ﻣﺎﯾﻮ أﯾﺎر 2011. ﺗﻢ ﺗﺤﺪﯾﺚ ھﺬه اﻟﻮﺛﯿﻘﺔ ﻟﻼﺟﺎﺑﺔ ﻋﻦ أﺳﺌﻠﺔ إﺿﺎﻓﯿﺔ ﺗﻢ اﺳﺘﻼﻣﮭﺎ ﻣﻨﺬ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﺼﺎدرة ﻋﺎم 2011. 3 ﻷﻏﺮاض ھﺬا اﻟﺘﻮﺟﯿﮫ، ﯾﻌﻨﻲ اﻟﻤُﺼﻄﻠﺢ"اﻟﻮاﻟﺪي" أﯾﻀﺎ اﻟﻮﺻﻲ أو ﺷﺨﺼًﺎ ﻣﺴﺆوﻻ آﺧﺮ وﻓﻘًﺎ ﻟ ﻠﻘﺎﻧﻮن اﻟﻤﺤﻠﻲ أو ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ. [OCR-00072-AR] اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 2 أ ﺳﺎس ﻋِ ﺮﻗﮭﻢ أو ﻋِ ﺮق آﺑﺎﺋ ﮭﻢ اﻟﻔﻌﻠﻲ أو اﻟﻤﺘﺼﻮﱠر ، أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ أو ، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة، أو أي ﻋﻨﺼﺮ آﺧﺮ ﻏﯿﺮ ﺟﺎﺋﺰ. ﯾﺠﺐ ﻣﻌﺎﻣﻠﺔ ﺟﻤﯿﻊ اﻟﻄﻼب ﺑﺎﻟﺘﺴﺎوي. 4 ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ﻣﺮاﺟﻌﺔ ﻗﺎﺋﻤﺔ اﻟﻮﺛﺎﺋﻖ اﻟﺘﻲ ﯾﻤﻜﻦ أن ﯾﺘﻢ اﺳﺘﺨﺪاﻣﮭﺎ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أن أ ﯾﺔ وﺛﺎﺋﻖ ﻣﻄﻠﻮﺑﺔ ﻻ ﺗﻤﻨﻊ أو ﺗﻌﯿﻖ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ أي طﺎﻟﺐ ﻟ ﻠﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ إذا ﻛﺎن اﻟﻄﺎﻟﺐ أو أﺑﻮﯾﮫ أو أوﻟﯿﺎء أﻣﺮه ال نولمحي وﺛﺎﺋﻖ ﺛﺒﻮﺗﯿﺔ. ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، ﺑﯿﻨﻤﺎ ﯾﻤﻜﻦ أن ﯾﺸﻤﻞ اﺧﺘﯿﺎر اﻟﻤﻨﻄﻘﺔ اﻟ ﮭﻮﯾﺔ اﻟﺼﺎدرة ﻋﻦ اﻟﻮﻻﯾﺔ أو رﺧﺼﺔ اﻟﻘﯿﺎدة اﻟﺼﺎدرة ﻷﺣﺪ اﻷﺑﻮﯾﻦ أو ﻟﻮﻟﻲ اﻷﻣﺮ ﻣﻦ ﺿﻤﻦ وﺛﺎﺋﻖ أﺧﺮى ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﻻ ﯾﺠﻮز ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ طﻠﺐ وﺛﯿﻘﺔ ﻛﮭﺬه ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ أو ﻹﻏﺮاض أﺧﺮى ﺑﺤﯿﺚ ﯾﻤﻜﻦ ﻟﮭﺬا اﻟﻄﻠﺐ أن ﯾﻤﻨﻊ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ اﻟ ﻄﺎﻟﺐ اﻟﺬي ﻟﻢ ﯾﻜﻦ أﺑﻮ ه ا ﯾﺤﻤﻼن وﺛﺎﺋﻖ ﻟ ﻠﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ. س – 4. ھﻞ ﯾﻤﻜﻦ ﺎﻄﻟﻠ ﻟﺐ اﻟﺬي ﯾﻜﻮن طﻔﻼ ﻣُﺸﺮﱠدً ا ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ طﻔﻞ ﻣﺸﺮد ﻏﯿﺮ ﻣﻮﺛﻖ، إﺛﺒﺎت اﻹﻗﺎﻣﺔ ﻓﻲ ﻣﻨﻄﻘﺔ ﻟﻜﻲ ﯾُﺴﺠﻞ ﻓﻲ ﻣﺪرﺳﺔ اﻟﻤﻨﻄﻘﺔ؟ ج – 4. ﻛﻼ. ﺣﺘﻰ ﻟﻮ ﻛﺎن ﻟﺪى اﻟﻤﻨﻄﻘﺔ ﻣﺘﻄﻠﺒﺎت ﻣﺸﺮوﻋﺔ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ، ﯾﺠﺐ ﻋﻠﯿﮭﺎ اﺳﺘﺜﻨﺎء ﺟﻤﯿ ﻊ اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺬﯾﻦ ﯾﻌﺘﺒﺮو ن ﻣﺸﺮدﯾﻦ وﻓﻘﺎ ﻟﻘﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ. ﻟﮭﺆﻻء اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺤﻖ ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ، ﺣﺘﻰ ﻟﻮ ﻟﻢ ﯾﺘ ﻤ ﻜﻦ أھﻠﮭﻢ ﻣﻦ إﺑﺮاز اﻟﻮﺛﺎﺋﻖ اﻟﺘﻲ ﺗﻜﻮن ﻣﻄﻠﻮﺑﺔ ﻹﺛﺒﺎت اﻹﻗﺎﻣﺔ. ﯾﺤﺪد ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻤﺼﻄﻠﺢ"ا ﻷطﻔﺎل وا ﻟﺸﺒﺎن اﻟﻤﺸﺮدﯾﻦ" ﻛﻤﺎ ﯾﺸﻤﻞ، ﺟﺰﺋﯿًﺎ،" اﻷطﻔﺎل واﻟ ﺸﺒﺎن اﻟﺬﯾﻦ ﯾﺸﺎرﻛﻮن أﺷﺨﺎﺻﺎ آﺧﺮﯾﻦ اﻟﺴﻜﻦ ﻧﺘﯿﺠﺔ ﺿﯿﺎع ﻣﻨﺎزﻟﮭﻢ، أو ﻧﺘﯿﺠﺔ ﻣﺼﺎﻋﺐ اﻗﺘﺼﺎدﯾﺔ، أو أﺳﺒﺎب ﻣﻤﺎﺛﻠﺔ؛ ﯾﻌﯿﺸﻮن ﻓﻲ ﻣﻮﺗﯿﻼت، ﻓﻨﺎدق، ﺣﺪاﺋﻖ اﻟﻌﺮﺑﺎت اﻟﻤﻘﻄﻮرة، أو أﻣﺎﻛﻦ اﻟﺘﺨﯿﯿﻢ ﻧﻈﺮًا ﻟﻌﺪم وﺟﻮد ﺳﻜﻦ ﺑﺪﯾﻞ ﻣﻨﺎﺳﺐ ؛ ﯾﻌﯿﺸﻮن ﻓﻲ ﻣﻼﺟﺊ طﻮارئ أو اﻧ ﺘﻘﺎﻟﯿﺔ؛ أو ﻣﺘﺮوﻛﯿﻦ ﻓﻲ اﻟﻤﺴﺘﺸﻔﯿﺎت؛ أو ﺑﺎﻧﺘﻈﺎر وﺿﻌﮭﻢ ﺗﺤﺖ اﻟﺮﻋﺎﯾﺔ اﻟﺒﺪﯾﻠﺔ،" وﻛﺬﻟﻚ أطﻔﺎل ﻋﻤﺎل اﻟﺰراﻋﺔ اﻟﻤﮭﺎﺟﺮﯾﻦ. ﺗﻮﺟﺪ ﻣﻌﻠﻮﻣﺎت إﺿﺎﻓﯿﺔ ﺗﺨﺘﺺ ﺑﻘﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ ﻋﻠﻰ اﻟﻤﻮﻗﻊ gov/programs/homeless/guidance. pdf www. ed.. س – 5. ﻛﯿﻒ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ إظﮭﺎر اﻟﺘﺰاﻣﮭﻢ ﺑﺸﺮوط اﻟﻤﺪرﺳﺔ ﻣﻦ ﺣﯿﺚ اﻟﻌﻤﺮ ؟ ج – 5. ﻛﻤﺎ ھﻮ اﻟﺤﺎل ﺑﺎﻟﻨﺴﺒﺔ ﻟﺸﺮوط اﻹﻗﺎﻣﺔ، ﺗﺨﺘﻠﻒ اﻟﻘﻮاﻧﯿﻦ ﺑﯿﻦ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺣﻮل أي ﻣﻦ اﻟﻮﺛﺎﺋﻖ ﯾﻤﻜﻦ ﻟﻠﺘﻼﻣﯿﺬ إﺑﺮازھﺎ ﻟﯿﺒﺮھﻨﻮا ﻋﻠﻰ أﻧﮭﻢ ﯾﺴﺘﻮﻓﻮن ﺷﺮوط اﻟﻤﻨﻄﻘﺔ أو اﻟﻮﻻﯾﺔ اﻟﺘﻲ ﺗﺤﺪد اﻟﺤﺪ اﻷﻋﻠﻰ واﻷدﻧﻰ ﻣﻦ اﻟﻌﻤﺮ، وﺗﻘﺒﻞ اﻟﺴﻠﻄﺎت اﻟﻘﻀﺎﺋﯿﺔ ﻋﺎدة وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻟﮭﺬا اﻟﻐﺮض. ووﻓﻘﺎ ﻟﻠﻤﻨﻄﻘﺔ أو اﻟﻮﻻﯾﺔ، ﻓﯿﻤﻜﻦ ﻟﻮﺛﺎﺋﻖ ﺑﺪﯾﻠﺔ أن ﺗﺸﻤﻞ و ﻟﻜﻦ ﻻ ﺗﻘﺘﺼﺮ ﻋﻠﻰ: ﺷﮭﺎدة دﯾﻨﯿﺔ، ﺷﮭﺎدة ﻣﻦ ﻣﺴﺘﺸﻔﻰ أو طﺒﯿﺐ ﺗﺒﯿﻦ ﺗﺎرﯾﺦ اﻟﻮﻻدة؛ ﺗﺪوﯾﻨﺎ ﻓﻲ اﻟﻜﺘﺎب اﻟﻤﻘﺪس اﻟﺨﺎص ﺑﺎﻟﻌﺎﺋﻠﺔ؛ ﺳﺠﻞ ﺗﺒﻨﻲ؛ إﻓﺎدة ﺧﻄﯿﺔ ﻣﺸﻔﻮﻋﺔ ﺑﺎﻟ ﻦﯿﻤﯿ ﯾﺆدﯾﮭﺎ أﺣﺪ اﻟﻮاﻟﺪﯾﻦ أو وﻟﻲ اﻷﻣﺮ ؛ ﺷﮭﺎدة ﻣﯿﻼد، ﺳﺠﻼت ﻣﺪرﺳﺔ ﺳﺎﺑﻘﺔ ﺗﻢ اﻟﺘﺤﻘﻖ ﻣﻨﮭﺎ أو أي وﺛﺎﺋﻖ أﺧﺮى ﯾﺠﯿﺰھﺎ اﻟﻘﺎﻧﻮن. ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﺗﻮﻋﯿﺔ اﻟﻮاﻟﺪﯾﻦ ﺑﺄﯾﺔ ﺑﺪاﺋﻞ ﺗﻜﻮن ﻣﻮﺟﻮدة ﻛﺠﺰء ﻣﻦ ﺟﮭﻮدھﻢ ﻟﻀﻤﺎن ﺑﯿﺌﺔ ﺗﺮﺣﯿﺒﯿﺔ وﺷﺎﻣﻠﺔ ﻟﺠﻤﯿﻊ اﻟﻄﻼب. طﻠﺒﺎت اﻟﻮﺛﺎﺋﻖ ﻛﺸﮭﺎدات اﻟﻤﯿﻼد ﯾﺠﺐ أن ﻻ ﺗﻤﻨﻊ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ أو ﺗﺜﺒﻂ ﻋﺰﯾﻤﺔ أي طﺎﻟﺐ ﻣﺴﺘﻘﺒﻠﻲ ﻣﻦ اﻟﺘﺴﺠﯿﻞ واﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟ ﻄﺎﻟﺐ اﻟﺬي ﻻ ﯾﺤﻤﻞ وﺛﺎﺋﻖ ﻗﺎﻧ ﻮﻧﯿﺔ أو اﻟﺬي ﻟﮫ أﺑﻮ ن ا ﻻ ﯾﺤﻤﻼن وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ ، أو طﻔﻞ أو ﺷﺎب ﻣﺸﺮد ﻛﻤﺎ ھﻮ ﻣﻨﺼﻮص ﻋﻠﯿﮫ ﻓﻲ ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ ) أﻧﻈﺮ – س 4.(، أﻋﻼه ﻻ ﯾﺠﻮز ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻨﻊ أو ﺗﺜﺒﯿﻂ ﻋﺰﯾﻤﺔ أي طﺎﻟﺐ ﻣﻦ اﻟﺪوام ﻓﻲ اﻟﻤﺪرﺳﺔ ﻷن اﻟ ﻄﺎﻟﺐ ﻻ ﯾ ﻤﻠﻚ ﺷﮭﺎدة ﻣﯿﻼد أو ﻻ ﯾﺤﻤﻞ ﺳﺠﻼت ﺗﺸﯿﺮ إﻟﻰ وﻻدﺗﮫ ﻓﻲ ﻣﻜﺎن أﺟﻨﺒﻲ، ﻣﺜﻞ ﺷﮭﺎدة ﻣﯿﻼد أﺟﻨﺒﯿﺔ. وﻻ ﯾﺠﻮز أﯾﻀﺎ أن ﺗﻤﯿﺰ طﻠﺒﺎت اﻟﻮﺛﺎﺋﻖ، أو ﯾﻜﻮن ﻟﮭﺎ ﺗﺄﺛﯿﺮ اﻟﺘﻤﯿﯿﺰ، ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. ﯾﺠﺐ أن ﯾﻌﺎﻣﻞ ﺟﻤﯿﻊ اﻟﻄﻼب ﺑﺎﻟﺘﺴﺎوي أﺛﻨﺎء ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ. 4 ﯾﻤﻨﻊ اﻟﺘﺸﺮﯾﻊIV ﻓﻲ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎم 1964 ، واﻟﺬي وﺿﻊ ﻣﻮﺿﻊ اﻟﺘﻨﻔﯿﺬ ﻣﻦ ﻗﺒﻞ وزارة اﻟﻌﺪل، اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻦ اﺗﺨﺎذ إﺟﺮاءات ﺗﺤﺮم اﻟﻄﻼب ﻣﻦ اﻟﺤﻤﺎﯾﺔ اﻟﻤﺘﺴﺎوﯾﺔ اﻟﺘﻲ ﺗﻤﻨﺤﮭﺎ اﻟﻘﻮاﻧﯿﻦ. اﻟﺘﺸﺮﯾﻊ VI ﻓﻲ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎم1964 ، واﻟﺬي وﺿﻊ ﻣﻮﺿﻊ اﻟﺘﻨﻔﯿﺬ ﻣﻦ ﻗﺒﻞ وزارة اﻟﺘﻌﻠﯿﻢ، وﻣﻦ ﻗﺒﻞ وزارة اﻟﻌﺪل ﺑﻌﺪ إﺣﺎﻟﺘﮫ ﻣﻦ وﻛﺎﻟﺔ ﺗﻤﻮﯾﻞ ﻓﺪراﻟﯿﺔ ﻣﻦ ﺧﻼل اﻟﺘﺪﺧﻞ ﻓﻲ دﻋﻮى ﻗﻀﺎﺋﯿﺔ ﻗﺎﺋﻤﺔ، ﯾﻤﻨﻊ اﻟﺘﻤﯿﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِﺮق أو اﻟﻠﻮن أو اﻷﺻﻞ اﻟﻘﻮﻣﻲ. اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 3 ﻋﻼوة ﻋﻠﻰ ذﻟ ﻚ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ال نأ ﺗﺴﺘﺨﺪم ﺷﮭﺎدة ﻣﯿﻼد اﻟ ﻄﺎﻟﺐ أو وﺛﺎﺋﻖ أﺧﺮى ﯾ ﻘﺪﻣﮭﺎ أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ ﻛﺄﺳﺎس ﻟﻼﺳﺘﻔﺴﺎر ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﺎ ﻟ ﻄﺎﻟﺐ ، أو وﺿﻊ أﺑﻮﯾﮫ أو أﺑﻮﯾﮭﺎ، أو أي أﻓﺮاد آﺧﺮﯾﻦ ﻓﻲ اﻟﻌﺎﺋﻠﺔ. ﻣﻦ اﻟﻤﺤﺘﻤﻞ أن ﯾﻜﻮن ﻟﻄﻠﺒﺎت ﻛﮭﺬه ﺗﺄﺛﯿﺮ ﻻ ﯾﺸﺠﻊ ﻋﻠﻰ ﺗﺴﺠﯿﻞ ﻄﺎ اﻟ ﻟﺐ أو اﻟﻄﺎﻟﺒﺔ ﻋﻠﻰ أﺳﺎس وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﮫ أو ﺑﮭﺎ. س – 6. اذام ﻟﻮ ﻋﺎرض أﺣﺪ اﻷﺑﻮﯾﻦ ﺗﻘﺪﯾﻢ ﻧﺴﺨﺔ ﻣﻦ ﺷﮭﺎد اﻟ ﻤﯿﻼد اﻷﺟﻨﺒﯿﺔ ﻟﻺ ﺑﻦ أو اﻹﺑﻨﺔ، ﺧﻮﻓًﺎ ﻣﻦ أن ذﻟﻚ ﻗﺪ ﯾﺆدي إﻟﻰ أﺳﺌﻠﺔ ﺣﻮل وﺿﻊ اﻟﮭﺠﺮة ﺑﺎﻟﻨﺴﺒﺔ ﻟﻸﺑﻮﯾﻦ أو ﺟﻨﺴﯿﺔ اﻷﺑﻮﯾﻦ؟ – ج6. ﯾﺘﻢ ﺗﺸﺠﯿﻊ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻋﻠﻰ اﺗﺨﺎذ ﺧﻄﻮات اﺳﺘﺒﺎﻗﯿﺔ ﻟﺘﻮﻋﯿﺔ اﻵ ﺑﺎء ﺣﻮل ﺣﻘﻮق أطﻔﺎﻟﮭﻢ وﻹﻋﺎدة طﻤﺄﻧﺘﮭﻢ ﺑﺄن أطﻔﺎﻟﮭﻢ ﻣُﺮﺣﺐ ﺑﮭﻢ ﻓﻲ ﻣﻨﺎطﻘﮭﻢ اﻟﺘﻌﻠﯿﻤﯿﺔ. ﻓﻌﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، ﺗﺴﻤﺢ ﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ ﻋﺎدة ﻟﻠﻤﻨﻄﻘﺔ ﺑﺎﺳﺘﺨﺪام وﺛﺎﺋﻖ ﻣﺨﺘﻠﻔﺔ ﻹﺛﺒﺎت ﻋﻤﺮ اﻟﻄﻔﻞ. ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ا ﻹﻋﻼن ﺑﺄﻧﮭﺎ ﺳﺘﺴﺘﺨﺪم ﺷﮭﺎدة اﻟﻤﯿﻼد اﻷﺟﻨﺒﯿﺔ، ﺳﺠﻞ اﻟﻤﻌﻤﻮدﯾﺔ، أو وﺛﺎﺋﻖ ﺑﺪﯾﻠﺔ ﺑﻨﻔﺲ اﻟﻄﺮﯾﻘﺔ اﻟﺘﻲ ﺗﺴﺘﺨﺪ م ﻓﯿﮭﺎ ﺷﮭﺎدة اﻟﻤﯿﻼد اﻷﻣﺮﯾﻜﯿﺔ، ﺳﺠﻞ اﻟﻤﻌﻤﻮدﯾﺔ، أو وﺛﯿﻘﺔ ﺑﺪﯾﻠﺔ: ﻓﻘﻂ ﻹﺛﺒﺎت ﺮﻋﻤ اﻟﻄﻔﻞ. وﻛﻤﺎ ﺗﻢ ﺗﺄﻛﯿﺪه ﺳﺎﺑﻘﺎ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ ﺗﻄﺒﯿﻖ ﻗﻮاﻧﯿﻨﮭﺎ وﻣﻌﺎﯾﯿﺮھﺎ ﻟﺘﻮﺛﯿﻖ اﻟﻌ ﻤﺮ أو اﻹﻗﺎﻣﺔ ﺑﻨﻔﺲ اﻟﻄﺮﯾﻘﺔ ﻟﻜﻞ ﺷﺨﺺ، ﺑﻐﺾ اﻟﻨﻈﺮ ﻋﻦ اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ ، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة. اﻟﻄﻔﻞ اﻟﻤﻮﻟﻮد ﻓﻲ ﺑﻠﺪ أﺟﻨﺒﻲ وﻏﯿﺮ ﻗﺎدر أو ﻏﯿﺮ راﻏﺐ ﻓﻲ ﺗﻘﺪﯾﻢ ﺷﮭﺎدة ﻣﯿﻼد، ﯾﺠﺐ أن ﺗﻜﻮن ﻟﮫ ﻧﻔﺲ اﻟﺨﯿﺎرات ﻓﻲ اﻟﺘﺴﺠﯿﻞ ﻓﻲ اﻟﻤﺪرﺳﺔ و ﯾﺠﺐ أن ﻻ ﯾﻌﺎﻣﻞ ﺑﺄي ﺷﻜﻞ ﻣﺨﺘﻠ ﻒ ﻋﻦ طﻔﻞ أﻣﺮﯾﻜﻲ اﻟﺠﻨﺴﯿﺔ ﻻ ﯾﻤﻠﻚ أو ﺑﺸﻜﻞ آﺧﺮ ﻗﺪ ﻻ ﯾﺘﻤﻜﻦ ﻣﻦ إﺑﺮاز ﺷﮭﺎدة ﻣﯿﻼد. – س7. ﻓﻲ ﺿﻮء رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ، ھﻞ يغبني نا ﺗﻤﺘﻨﻊ اﻟﻤﻨﺎطﻖ ﻋﻦ طﻠﺐ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠ ﻄﺎﻟﺐ ؟ ج – 7. ﻻ ﺗﻤﻨﻊ اﻟﺤﻜﻮﻣﺔ اﻷﻣﺮﯾﻜﯿﺔ اﻟﻮﻻﯾﺎت أو اﻟﻤﻨﺎطﻖ ﻣﻦ ﺗﺤﺼﯿﻞ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠﺘﻼﻣﯿﺬ اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ أو اﻟﺤﺎﻟﯿﯿﻦ. ﻣﻊ ذﻟﻚ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ أن ﺗ ﻘﺮر ﻓﯿﻤﺎ إذا ﻛﺎن ﻟﺪﯾﮭ ﺎﺳﺒﺒ ﺎ ﻣﺴﻤﻮح ﺑﮫ اينوناق ﺤﺼﻠﻟ ﻮل ﻋﻠﻰ ھﺬه اﻟﻤﻌﻠﻮﻣﺎت. إذا اﺧﺘﺎر ت ﺗﺤﺼﯿﻞ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻋﻠﯿﮭ ﺎ اﺗﺨﺎذ ﺧﻄﻮات ﺗﻀﻤﻦ ﺧﺼﻮﺻﯿﺔ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ وأﻧ ﮭﺎ ﺗُﺨﺰﱠن ﺑﺸﻜﻞ آﻣﻦ. إﺿﺎﻓﺔ إﻟﻰ ذﻟﻚ، ﻋﻠﯿﮭ ﺎ اﺗﺒﺎع اﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ اﻟﺘﻲ ﺗﻨﻈﻢ اﺳﺘﺨﺪام ﺗﻠﻚ اﻟﻤﻌﻠﻮﻣﺎت. ﺑﻤﻮﺟﺐ ا ﻟﻘﻮاﻧﯿﻦ اﻟﻨﺎﻓﺬة، ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، إذا طﻠﺒﺖ ﻣﻨﻄﻘﺔ ﻣﺎ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻋﻠﯿﮭﺎ ﺗﺒﻠﯿﻎ اﻷﻓﺮاد أ ن اﻹﻓﺼﺎح ﻋﻨﮭﺎ ﯾﻜﻮن طﻮﻋﯿﺎ، وﯾﺠﺐ ﻋﻠﯿﮭﺎ ﺷﺮح اﻷﺳﺲ اﻟﺘﺸﺮﯾﻌﯿﺔ أو ﻏﯿﺮھﺎ وراء طﻠﺐ اﻷرﻗﺎم وﻛﯿﻒ ﺳﺘﻘﻮم اﻟﻤﻨﻄﻘﺔ ﺑﺎﺳﺘﺨﺪام اﻷرﻗﺎم. أﻧﻈﺮ ﻗﺎﻧﻮن اﻟﺨﺼﻮﺻﯿﺔ ﻟﻌﺎم 1974 ، اﻟﻨﺸﺮة إل. رﻗﻢ 579 - 93، اﻟﺠﺰء 5 و اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ رﻗﻢ 7 اﻟﺠﺰء552 ،(أ)ﻣﻼﺣﻈﺔ اﻟﻤﺘﻮﻓﺮ ﻋﻠﻰ: http://www. ssa. gov/OP_Home/comp2/F093-579. html. وﻛﻤﺎ ﺗﻮﺿﺤﮫ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ، ﻻ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ ﺣﺮﻣﺎن اﻟ ﻄﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ إذا اﺧﺘﺎر ھﻮ أو ھﻲ )أو أﺑﻮﯾﮭﻤ ﺎ أو أوﻟﯿﺎء أﻣﻮرھﻤ ﺎ ( ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ اﻟﺨﺎص ﺑﺎﻟ ﻄﺎﻟﺐ. 5 ﻟﺪى اﻟﻤﻨﺎطﻖ ﺑﺪاﺋﻞ ﻋﻦ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ. ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، إذا ﺳﻌﺖ اﻟﻤﻨﻄﻘﺔ ﻷن ﯾﺤﻤﻞ اﻟﻄﻼب أرﻗﺎم ھﻮﯾﺔ، ﻓﯿﻤﻜﻨﮭﺎ إﻋﻄﺎء ﻛﻞ طﺎﻟﺐ رﻗﻤﺎ ﯾﺘﻢ اﺧﺘﯿﺎره ﻋﺸﻮاﺋﯿﺎ. وﺑﮭﺬه اﻟﻄﺮﯾﻘﺔ، ﺗﺘﺠﻨﺐ اﻟﻮﻻﯾﺔ أو اﻟﻤﻨﻄﻘﺔ أي أﺛﺮ ﻂﺜﺒﻣُ ﻗﺪ ﯾﺘﺮﻛﮫ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻋﻠﻰ ﺗﺴﺠﯿﻞ اﻟﻄﻼب ﺑﺴﺐ اﻟﻌِﺮق أو اﻟﻠﻮن، اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. أو اﻟﺠﻨﺴﯿﺔ، أو وﺿﻊ اﻟﮭﺠﺮة اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﺘﻲ ﺗ ﻔﻀﻞ طﻠﺐ أرﻗﺎم اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ، ﻋﻠﯿﮭﺎ أن ﺗﻮﺿﺢ ﻓﻲ ﻛﺎﻓﺔ وﺛﺎﺋﻖ اﻟﺘﺴﺠﯿﻞ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻻﺳﺘﻤﺎرات، اﻟﻤﻮاﻗﻊ اﻹﻟﻜﺘﺮوﻧﯿﺔ، واﻻﺗﺼﺎﻻت ﻣﻊ أوﻟﯿﺎء اﻷﻣﻮر، أن ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻠﻄﻔﻞ أﻣﺮ طﻮﻋﻲ، وأن اﺧﺘﯿﺎر ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ ﻟﻦ ﯾﻤﻨﻊ اﻟﻄﻔﻞ ﻣﻦ اﻟﺘﺴﺠﯿﻞ. س – 8 (. ﻛﯿﻒ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﺘﻔﺮﯾﻖ ﺑﯿﻦ )أ( اﻟﻤﻌﻠﻮﻣﺎت اﻟﺘﻲ ﻋﻠﯿﮭﺎ أو ﯾﺘﻮﺟﺐ ﻋﻠﯿﮭﺎ ﺗﺤﺼﯿﻠﮭﺎ، و )ب اﻟﻤﻌﻠﻮﻣﺎت اﻟﺘﻲ ﻻ ﯾﺠﻮز ﺗﺤﺼﯿﻠﮭﺎ ﻷن ذﻟﻚ ﯾﻤﻜﻦ أن ﯾﺜﺒﻂ اﻟﺘﺴﺠﯿﻞ أو اﻟﺪوام؟ ج – 8. ھﻨﺎك ﺣﺪ أدﻧﻰ ﻣﻦ اﻟﻤﻌﻠﻮﻣﺎت ﯾﻄﻠﺐ ﻋﺎدة ﻣﻦ اﻟﻤﻨﻄﻘﺔ ﺗﺤﺼﯿﻠﮫ ﺑﻤﻮﺟﺐ ﻗﺎﻧﻮن اﻟﻮﻻﯾﺔ ﻟﯿﺘﻤﻜﻦ أي طﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ ، ﻛﺈﺛﺒﺎت اﻟﻌﻤﺮ، ﺳﺠﻞ اﻟﺘﻄﻌﯿﻢ، واﻹﻗﺎﻣﺔ ﻓﻲ اﻟﻤﻨﻄﻘﺔ. ﻋﻠﻰ اﻟﻮﻻﯾﺔ واﻟﻤﻨﻄﻘﺔ اﻟﻌﻤﻞ وﻓﻘًﺎ ﻟﺪﺳﺘﻮر اﻟﻮﻻﯾﺎت اﻟﻤﺘﺤﺪة اﻷﻣﺮﯾﻜﯿﺔ 5 ﺑﺸﻜﻞ ﻣﻤﺎﺛﻞ، ﻻ ﺗﺴﺘﻄﯿﻊ اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ إﻧﻜﺎر ﺣﻖ اﻟﻄﺎﻟﺐ ﻓﻲ اﻟﺘﺴﺠﯿﻞ إذا اﺧﺘﺎر أﺑﻮ ا ه أو أﺑﻮ ا ھﺎ ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ اﻟﺨﺎص ﺑﮫ أو ﺑﮭﺎ. واﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ وﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ اﻟﺴﺎرﯾﺔ ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟﺘﺰاﻣﮭﻢ ﺑﻌﺪم اﻟﺘﻤﯿﯿﺰ، أو ﺗﻨﻔﯿﺬ ﺳﯿﺎﺳﺎت ﻟﮭﺎ اﻷﺛﺮ ﻓﻲ اﻟﺘﻤﯿﯿﺰ ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق، اﻟﻠﻮن، أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ. وﺑﺎﻟﻘﯿﺎم ﺑﺬﻟﻚ اﻟﻌﻤﻞ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﺗﻘﯿﯿﻢ ﺳﯿﺎﺳﺎﺗﮭ ﺎ ةيلاحلا ﻟﺘﺤﺪﯾﺪ ﻓﯿﻤﺎ إذا ﺗ ﺖﻛﺎﻧ ﻘﻮم ﺑﺄي ﻋﻤ ﻞ ﯾﻤﻜﻦ أن ﯾﺆدي، وﻟﻮ ﻋﻦ ﻏﯿﺮ ﻗﺼﺪ، إﻟﻰ إﺣﺒﺎط ﻋﻤﻠﯿﺔ ﺗﺴﺠﯿﻞ اﻹطﻔﺎل اﻟﺬﯾﻦ ﻻ ﯾﺤﻤﻠﻮن أي وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ، ﻛﻄﻠﺐ أوراق اﻟﮭﺠﺮة ، أو أرﻗﺎم اﻟﻀ ﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ أو رﺧﺼﺔ اﻟﻘﯿﺎدة أو ھﻮﯾﺔ ﺻﺎدرة ﻣﻦ اﻟﻮﻻﯾﺔ ﻟﻮﻟﻲ اﻷﻣﺮ. ﯾﺠﺐ ﺗﻐﯿﯿﺮ ﻣﺜﻞ ھﺬه اﻟﻤﻤﺎرﺳﺎت واﻟﺴﯿﺎﺳﺎت، ﻋﻨﺪ ﺗﺤﺪﯾﺪھﺎ، ﻹزاﻟﺔ أي أﺛﺮ ﯾﺤﺒﻂ ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ. س – 9. ﻷﺟﻞ ﺗﺠﻨﺐ إﺣﺒﺎط ﻋﻤﻠﯿﺔ اﻟﺘﺴﺠﯿﻞ ، ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ أي ﻣﻨﻄﻘﺔ ﺗﻌﻠﯿﻤﯿﺔ ﺗﺴﺠﯿﻞ اﻟﻄﻔﻞ اﻟﺬي ﯾﺄﺗﻲ إﻟﯿﮭﺎ وﺗﻄﻠﺐ اﻟﻮﺛﺎﺋﻖ ﻓﻲ وﻗﺖ ﻻﺣﻖ، ﺑﻌﺪ أن ﯾﺘﻢ ﺗﺴﺠﯿﻞ اﻟﻄﻔﻞ ﻓﯿﮭﺎ ؟ ج – 9. ﻛﻤﺎ ھﻮ ﻣﺪون أﻋﻼه، ﯾﻤﻜﻦ ﻟﻠﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﻄﻠﺐ ﻣﻦ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ ﻓﯿﮭﺎ أن ﯾﻘﺪﻣﻮا إﺛﺒﺎﺗﺎ ﻋﻠﻰ إﻗﺎﻣﺘﮭﻢ ﻓﻲ اﻟﻤﻨﻄﻘﺔ و/ أو ﺑ ﺎﻟﻌﻤﺮ ﻗﺒﻞ ﺗﺴﺠﯿﻠﮭﻢ ، ﻣﺎ ﻋﺪا إذا ﻛﺎن أي طﻔﻞ أو ﺷﺎب ﯾﻌﺘﺒﺮ ﻣﺸﺮدا ﺑﻤﻮﺟﺐ ﻗﺎﻧﻮن ﻣﺎﻛﱢﻨﻲ- ﭭ ﯾﻨﺘﻮ اﻟﻔﺪراﻟﻲ ﻟﻤﺴﺎﻋﺪة اﻟﻤﺸﺮدﯾﻦ. وﻣﻊ ذﻟﻚ، ﯾﺠﻮز أﯾﻀﺎ ﻟﻠﻤﻨﺎطﻖ أن ﺗﺨﺘﺎر اﻻﻧﺘﻈﺎر وﻋﺪم طﻠﺐ وﺛﺎﺋﻖ إﺿﺎﻓﯿﺔ ﯾﻤﻜﻦ أن ﺗﻜﻮن ﻣﻄﻠﻮﺑﺔ ﺑﻤﻮﺟﺐ ﻗﻮاﻧﯿﻦ اﻟﻮﻻﯾﺔ أو اﻟﻘﻮاﻧﯿﻦ اﻟﻔﺪراﻟﯿﺔ ﻣﺜﻞ اﻟ ﺒﯿﺎﻧﺎت اﻟﺪﯾﻤﻮﻏﺮاﻓﯿﺔ ﻟﻠ ﻄﺎﻟﺐ ، إﻻ ﺑﻌﺪ أن ﯾﻜﻮن اﻟﻄﻼب ﻗﺪ ﺗﺴﺠﻠﻮا. وﺑﺎﺧﺘﯿﺎرھﺎ اﻻﻧﺘﻈﺎر ﻟﺘﺤﺼﯿﻞ ﻣﻌﻠﻮﻣﺎت إﺿﺎﻓﯿﺔ، ﻗﺪ ﺗﺆدي ﺗﻠﻚ اﻟﻤﻨﺎطﻖ إﻟﻰ ﺧﻠﻖ ﺟﻮ أﻛﺜﺮ ﺗﺮﺣﯿﺒﺎ وﺷﻤﻮﻻ ﻟﺠﻤﯿﻊ اﻟﻄﻼب اﻟﻤﺴﺘﻘﺒﻠﯿﯿﻦ. طﻠﺒﺎت اﻟﻮﺛ ﺎﺋﻖ ﯾﺠﺐ أن ﻻ ﺗﻤﯿﺰ أو ﯾﻜﻮن ﻟﮭﺎ ﺗﺄﺛﯿﺮ ﻓﻲ اﻟﺘﻤﯿﯿﺰ، ﻋﻠﻰ أﺳﺎس اﻟﻌِ ﺮق أو اﻟﻠﻮن أو اﻟﻤﻨﺸﺄ اﻟﻮطﻨﻲ.، اﻟﺠﻨﺴﯿﺔ أو وﺿﻊ اﻟﮭﺠﺮة س – 10. ﺑﻌﺪ ﺣﯿﺎزة اﻟﻤﻌﻠﻮﻣﺎت اﻟﺸﺨﺼﯿﺔ اﻟﺨﺎﺻﺔ ﺑﺎﻟﻄﺎﻟﺐ، ھﻞ ھﻨﺎك ظﺮوف ﯾﺠﻮز ﻟﻠﻤﺪرﺳﺔ ﻋﻨﺪھﺎ اﻟﻜﺸﻒ ﻋﻦ اﻟﻤﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﺘﻌﻠﯿﻢ ﺑﺪون ﻣﻮاﻓﻘﺔ اﻟﻄﺎﻟﺐ أو أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ؟ ج – 10. ھﻨﺎك ظﺮوف ﯾﺠﻮز ﻋﻨﺪھﺎ ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ اﻟﻜﺸﻒ ﻋﻦ ﻣﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﻄﺎﻟﺐ، ﻟﻜﻦ ھﺬه اﻟﻈﺮوف ﻣﺤﺪودة وﻣﻦ ﻏﯿﺮ اﻟﻤﺤﺘﻤﻞ ﺗﻄﺒﯿﻘﮭﺎ ﻓﻲ أﻏﻠﺐ اﻟﺤﺎﻻت اﻟﺘﻲ ﺗﻮاﺟﮭﮭﺎ اﻟﻤﻨﺎطﻖ اﻟﺘﻌﻠﯿﻤﯿﺔ. ﯾﻤﻨﻊ ﻗﺎﻧﻮن ﺣﻘﻮق اﻟﺘﻌﻠﯿﻢ واﻟﺨﺼﻮﺻﯿﺔ ﻟﻠﻌﺎﺋﻼت ﻟﻌﺎم 1974 (FERPA) ﻋﻤﻮﻣًﺎ اﻟﻤﻨﺎطﻖ اﻟﺪراﺳﯿﺔ اﻟﺘﻲ ﺗﺤﺼﻞ ﻋﻠﻰ ﺗﻤﻮﯾﻞ ﻓﺪراﻟﻲ ﻣﻦ وزارة اﻟﺘﻌﻠﯿﻢ ﻣﻦ ﻛﺸﻒ ﻣﻌﻠﻮﻣﺎت ﻣﻦ ﺳﺠﻼت اﻟﺘﻌﻠﯿﻢ اﻟﺨﺎﺻﺔ ﺑﺎﻟﻄﺎﻟﺐ واﻟﺘﻲ ﻟﻮﺣﺪھﺎ أو ﻣﺸﺘﺮﻛﺔ ﻣﻊ ﻣﻌﻠﻮﻣﺎت أﺧﺮى ﯾﻤﻜﻦ أن ﺗﺤﺪد ھﻮﯾﺔ اﻟﻄﺎﻟﺐ، ﺑﺪون ﻣﻮاﻓﻘﺔ ﺧﻄﯿﺔ ﻣﻦ أﺣﺪ اﻷﺑﻮﯾﻦ أو وﻟﻲ اﻷﻣﺮ أو اﻟﻄﺎﻟﺐ )إذا ﻛﺎن ﻋﻤﺮه 18 ﻋﺎﻣﺎ أو رثكأ أو إذا ﻛﺎن ﯾﻨﺘﻈﻢ ﻓﻲ ﻣﺆﺳﺴﺔ ﺗﻌﻠﯿﻢ ﻋﺎﻟﻲ ﺑﻌﺪ اﻟﺪراﺳﺔ اﻟﺜﺎﻧﻮﯾﺔ(. اﻟﺮﺟﺎء اﻟﺮﺟﻮع إﻟ ﻰ اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ 20 اﻟﺠﺰء1232ج. ھﻨﺎﻟ ﻚ ﺑﻌﺾ اﻻﺳﺘﺜﻨﺎءات اﻟﻤﺤﺪودة ﻓﻲ ﻗﺎﻧﻮن ﺣﻘﻮق اﻟﺘﻌﻠﯿﻢ واﻟﺨﺼﻮﺻﯿﺔ ﻟﻠﻌﺎﺋﻼت ﻟﻌﺎم 1974 اﻟﻤﺘﻌﻠﻘﺔ ﺑﻄﻠﺐ وﺟﻮب اﻟﺤﺼﻮل ﻋﻠﻰ اﻟﻤﻮاﻓﻘﺔ اﻟﺨﻄﯿﺔ ﻗﺒﻞ اﻟﻜﺸﻒ ﻋﻦ ﻣﻌﻠﻮﻣﺎت ﺗﻌﺮﯾﻒ ﺷﺨﺼﯿﺔ ﻣﻦ ﺳﺠﻼت اﻟﻄﺎﻟﺐ اﻟﻤﺪرﺳﯿﺔ، أﻧﻈﺮ ﻗﺎﻧﻮن اﻟﻠﻮاﺋﺢ اﻟﻔﺪراﻟﯿﺔ 34 اﻟﺠﺰء99. 31 ، وﻛﺬﻟﻚ ظﺮوف ﻣﺤﺪودة وﻣﻌﺪودة ﯾُ ﻄﻠَ ﺐ ﻓﯿﮭﺎ وﻓﻘﺎ ﻟﻘﻮاﻧﯿﻦ اﻟﮭﺠﺮة اﻟﻔﺪراﻟﯿﺔ اﻟﺴﻤﺎح ﻟﻠﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﺑﺘﻮﻓﯿﺮ ﻣﻌﻠﻮﻣﺎ ت ﻣﺤﺪدة ﻋﻦ ﺗﻠﻤﯿﺬ ﻟﻜﯿﺎن ﺣﻜﻮﻣﻲ آﺧﺮ ﻓﺪراﻟﻲ أو ﻣﺤﻠﻲ أو ﺗﺎﺑﻊ ﻟﻠﻮﻻﯾﺔ. واﺣﺪة ﻣﻦ ﺗﻠﻚ اﻟﻈﺮوف ﺗﺘﻤﺜﻞ ﻓﻲ ﺣﺎﻟﺔ إﺻﺪار ﺗﺄﺷﯿﺮة ﻟﻐﯿﺮ اﻟﻤﮭﺎﺟﺮﯾﻦ ﻷﺣﺪ اﻟﻄﻠﺒﺔ — واﻟﻤﺤﺎﻓﻈﺔ ﻋﻠﻰ وﺿﻊ ﻋﺪم اﻟﮭﺠﺮة ﻟﺬﻟﻚ اﻟﻄﺎﻟﺐ — ﻣﺸﺮوطًﺎ ﺑﺪوام اﻟﻄﺎﻟﺐ ﻓﻲ ﻣﺪرﺳﺔ ﻣﻌﯿﻨﺔ. ﯾﺮﺟﻰ ﻣﻼﺣﻈﺔ أﻧﮫ ﻓﻲ ﺗﻠﻚ اﻟﺤﺎﻟﺔ، ﺗﻜﻮن ﻟﺪى اﻟﻤﻨﻄﻘﺔ اﻟﺘﻌﻠﯿﻤﯿﺔ ﻣﻌﻠﻮﻣﺎت ﻣﺴﺒﻘﺔ ﻋﻦ اﻟﻄﺎﻟﺐ واﻟﺘﻲ ﯾﻜﻮن اﻟﻄﺎﻟﺐ أو اﻟﻄﺎﻟﺒﺔ ﻗﺪ ﻗﺪﻣ ﺎ ھﺎ ﻟﻠﻤﺪرﺳﺔ ﺑﻐﺮض اﻟﺤﺼﻮل ﻋﻠﻰ اﻟﺘﺄﺷﯿﺮة اﻷﺳﺎﺳﯿﺔ، وﺑﻨﺎء ﻋﻠﯿﮫ ﻻ ﯾﻜﻮن ﻟﻠﻤﺪرﺳﺔ ﺳﺒﺐ ﻟﻠﻤﺒﺎدرة ﺑﻄﻠﺐ ﻣﻌﻠﻮﻣﺎت ﺣﻮل وﺿﻊ اﻟﮭﺠﺮة. س – 11. ﻛﯿﻒ ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ اﻟﺪراﺳﯿﺔ اﻟﺘﻮاﺻﻞ ﻣﻊ اﻷﺑﻮﯾﻦ يدودحملا اﻟﻤﻌﺮﻓﺔ ﺑﺎﻟﻠﻐﺔ اﻹﻧﻜﻠﯿﺰﯾﺔ ﺑﺸﺄن ﻣﺘﻄﻠﺒﺎت اﻟﺘﺴﺠﯿﻞ ؟ ج – 11. ﺑﺎﻟﻨﺴﺒﺔ ﻷﺑﻮﯾﻦ اﻟﻄﺎﻟﺐ يدودحملا اﻟﻤﻌﺮﻓﺔ ﺑ ﺎﻟﻠﻐﺔ اﻹﻧﻜﻠﯿﺰﯾﺔ نيذلاو ﯾﺴﻌﻮن ﺗﺴﺠﯿﻠﮫ ﺑﺎﻟﻤﺪرﺳﺔ، ﯾﺠﺐ ﻋﻠﻰ اﻟﻤﻨﻄﻘﺔ أن ﺗﻮﺻﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ اﻟﻤﺘﻌﻠﻘﺔ ﺑ ﺎﻟﺘﺴﺠﯿﻞ ﺑﻄﺮﯾﻘﺔ ھﺎدﻓﺔ – ﻣﺜﻼ، ﺗﻘﻮم ﺑﺘﺮﺟﻤﺔ اﻟﻮﺛﯿﻘﺔ إﻟﻰ ﻟﻐﺎت ﻏﯿﺮ اﻹﻧﻜﻠﯿﺰﯾﺔ أن و ﺗﺘﻮﻓﺮ ﻟﺪﯾﮭﺎ وﺳﯿﻠﺔ ﻹﺟﺎﺑﺔ نيوبألا ىلع اﻷﺳﺌﻠﺔ – ﻛﻤﺎ ھﻮ ﻣُﺸﺘﺮط ﻋﻠﯿﮫ ﻓﻲ اﻟﺘﺸﺮﯾﻊ VI ﻣﻦ ﻗﺎﻧﻮن اﻟﺤﻘﻮق اﻟﻤﺪﻧﯿﺔ ﻟﻌﺎ م 1964 ، اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ42 اﻟﺠﺰء2000د ، وﻗﺎﻧﻮن ﻓﺮص اﻟﺘﻌﻠﯿﻢ اﻟﻤﺘﺴﺎوﯾﺔ، اﻟﻘﺎﻧﻮن اﻷﻣﺮﯾﻜﻲ 20 اﻟﺠﺰء1703. وإن ﺗﻮﻓﺮت، ﻓﯿﻤﻜﻦ أن ﺗﺸﺘﻤﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ ﻋﻠﻰ وﺳﺎﺋﻞ ﺑﺪﯾﻠﺔ ﻹﺛﺒﺎت ﻣﺘﻄﻠﺒﺎت اﻹﻗﺎﻣﺔ وﻋﻤﺮ اﻟﻄﺎﻟﺐ اﻟﺬي ﺗﺴﻤﺢ ﺑﮭ ﺎ اﻟﻮﻻﯾﺔ. إذا ﻗﺎﻣﺖ اﻟﻤﻨﻄﻘﺔ ﺑﻄﻠﺐ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ، ﻗﺪ ﺗﺸﺘﻤﻞ اﻟﻤﻌﻠﻮﻣﺎت اﻷﺳﺎﺳﯿﺔ اﻟﮭﺎﻣﺔ ﻋﻠﻰ ﺣﻘﯿﻘﺔ أن اﻟﻤﻨﻄﻘﺔ ﻻ اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 4 ﺗ ﺴﺘﻄﯿﻊ ﺣﺮﻣﺎن أي طﺎﻟﺐ ﻣﻦ اﻟﺘﺴﺠﯿﻞ إن اﺧﺘﺎر اﻟﻄﺎﻟﺐ أو اﻟﻄﺎﻟﺒﺔ )أو أﺑﻮﯾﮫ، أﺑﻮﯾﮭﺎ أو أوﻟﯿﺎء أﻣﺮھﻤ ﺎ ( ﻋﺪم ﺗﻘﺪﯾﻢ رﻗﻢ اﻟﻀﻤﺎن اﻻﺟﺘﻤﺎﻋﻲ. ﺗﺪاﺑﯿﺮ ﻣﺴﺎﻧﺪة إﺿﺎﻓﯿﺔ ﯾﻤﻜﻦ ﻟﻠﻮﻻﯾﺎت أو اﻟﻤﻨﺎطﻖ اﺗﺨﺎذھﺎ س – 12. ﻣﺎذا ﯾﻤﻜﻦ ﻟﻠﻤﺪارس ﻋﻤﻠﮫ ﺑﺸﻜﻞ اﺳﺘﺒﺎﻗﻲ ﻟﺘﻈﮭﺮ ﻟﻸﺑﻮﯾﻦ أن أطﻔﺎﻟﮭﻢ ﻣﺮﺣﺐ ﺑﮭﻢ، ﺑﻐﺾ اﻟﻨﻈﺮ ﻋﻦ وﺿﻊ اﻟﮭﺠﺮة اﻟﺨﺎص ﺑﮭﻢ أو ﺟﻨﺴﯿﺘﮭﻢ؟ ج – 12. ﺗﺸﺠﻊ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﻮﻻﯾﺎت واﻟﻤﻨﺎطﻖ ﻋﻠﻰ ﻣﺮاﺟﻌﺔ ﺳﯿﺎﺳﺎت اﻟﺘﺴﺠﯿﻞ واﻟﻤﻤﺎرﺳﺎت ﺑﻌﻨﺎﯾﺔ ﻟﻠﺘﺄﻛﺪ ﻣﻦ أﻧﮭ ﺎ ﻣﺘﺴﺎوﻗ ﺔ ﻣ ﻊ اﻟﻘﺎﻧﻮن وﻟﯿﺲ ﻟﺪﯾﮭ ﺎ ﺗﺄﺛﯿﺮ ﯾﺜﺒﻂ اﺳﺘﻌﺪاد اﻷﺑﻮﯾﻦ ﻟ ﺘﺴﺠﯿﻞ أطﻔﺎﻟﮭﻢ. ﯾﺠﺐ ﺗﺼﯿﺢ ﺔ أﯾ ﻣﺸﺎﻛﻞ. إﺿﺎﻓﺔ إﻟﻰ ذﻟﻚ، ﺗﺸﺠﻊ وزارة اﻟﺘﻌﻠﯿﻢ ةيكيرمالا ووزارة اﻟﻌﺪل اﻟﻤﻨﺎطﻖ ﻋﻠﻰ أن ﺗﻜﻮن ﺳﺒّﺎﻗﺔ إﻟﻰ إﺑﻼغ اﻷﺑﻮﯾﻦ ﺑﺤﻘﮭﻤﺎ ﻓﻲ إرﺳﺎل أطﻔﺎﻟﮭﻤﺎ إﻟﻰ ﻣﺪرﺳﺔ ﻋﺎﻣﺔ. ﯾﻤﻜﻦ ﻟﻠﻤﻨﺎطﻖ، ﻋﻠﻰ ﺳﺒﯿﻞ اﻟﻤﺜﺎل، أن ﺗﻘﻮم ﺑﺎﻟﺘﻮاﺻﻞ ﻣﻊ اﻟﻤﺠﺘﻤﻌﺎت ﻹﺑﻼغ اﻷھﺎﻟﻲ ﺑﺄن ﺟﻤﯿﻊ اﻟﻄﻠﺒﺔ اﻟﻤﻘﯿﻤﯿﻦ ﻓﻲ اﻟﻤﻨﻄﻘﺔ ﻣُ ﺮﺣﱠﺐٌ ﺑﮭﻢ ﻟﻠﺪوام ﻓﻲ ﻣﺪارس اﻟﻤﻨﻄﻘﺔ. – س13. ھﻞ ﯾﺘﻮﺟﺐ ﻋﻠﻰ اﻟﻤﻨﺎطﻖ ﺗﻮﻓﯿﺮ اﻟﺘﺪرﯾﺐ ﻟﻤﻮظﻔﯿﮭﺎ ﺣﻮل ﻛﯿﻔﯿﺔ ﺗﺠﻨﺐ ﻣﺨﺎﻟﻔﺔ اﻟﻘﺎﻧﻮن ﻓﻲ ھﺬا اﻟﻤﺠﺎل؟ ج – 13. ﯾُﺸﺠﻊ ﺗﺪرﯾﺐ اﻟﻤﻮظﻔﯿﻦ ﻋﻠﻰ ﻣﺴﺘﻮى اﻟﻤﺪرﺳﺔ واﻟﻤﻨﻄﻘﺔ. ﻓﻲ اﻟﻨﮭﺎﯾﺔ ، ﺗﺘﺤﻤﻞ اﻟﻮﻻﯾﺔ واﻟﻤﻨﻄﻘﺔ اﻟﻤﺴﺆوﻟﯿﺔ اﻟﻘﺎﻧﻮﻧﯿﺔ ﻟﻀﻤﺎن ا ﻣﺘﺜﺎﻟﮭ ﺎ نوناقلاب اﻟﻔﺪراﻟﻲ. ﺗﺪرﯾﺐ اﻟﻤﻮظﻔﯿﻦ ﯾُﺴﮭﱢﻞ ﻋﻤﻠﯿﺔ اﻻﻣﺘﺜﺎل. س – 14. ﻣﺎ ھﻮ دور وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ (SEAs) ﻓﻲ ﺿﻤﺎن ﻋﺪم اﺳﺘﺒﻌﺎد اﻟﻄﻼب ﻣﻦ اﻟﻤﺪرﺳﺔ ﺑﺸﻜﻞ ﻏﯿﺮ ﺻﺤﯿﺢ؟ س – 14. اﻟﻤﻘﺼﻮد ﻣﻦ رﺳﺎﻟﺔ اﻟﺰﻣﯿﻞ اﻟﻌﺰﯾﺰ اﻟﺼﺎدرة ﻓﻲ6 ﻣﺎﯾﻮ/ أﯾﺎر2011 ، واﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ واﻟﻤﻌﺎد إﺻﺪارھﺎ ﻓﻲ 8 ﻣﺎﯾﻮ/ أﯾﺎر2014، ھﻮ ﺗﺬﻛﯿﺮ ﻛﻞ ﻣﻦ اﻟﻤﻨﺎطﻖ واﻟﻮﻻﯾﺎت ﺑﺎﻟﺘﺰاﻣﺎﺗﮭ ﺎ ﺑﻤﻮﺟﺐ اﻟﻘﺎﻧﻮن اﻟﻔﺪراﻟﻲ. ﻛﻤﺴﺘﻔﯿﺪ ة ﻣﻦ اﻟﺘﻤﻮﯾﻞ اﻟﻔﺪراﻟﻲ، ﻓﺈن وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﻣﺴﺆوﻟﺔ ﻋﻦ ﻣﺮاﻗﺒﺔ اﻻﻣﺘﺜﺎل نيناوقب ﻋﺪم اﻟﺘﻤﯿﯿﺰ اﻟﻔﺪراﻟﯿﺔ. ﺣﯿﺚ أن اﻟﻘﻮاﻧﯿﻦ اﻟﻤﺘﻌﻠﻘﺔ ﺑ ﺎﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس، ﺑﻤﺎ ﻓﯿﮭﺎ ﻣﺘﻄﻠﺒﺎت إﺛﺒﺎت اﻟﻌﻤﺮ واﻹﻗﺎﻣﺔ ﺗﺨﺘﻠﻒ ﻣﻦ وﻻﯾﺔ إﻟﻰ إﺧﺮى، ھﺬا ﻣﺠﺎل ﺗﻜﻮن ﻓﯿﮫ ﺣﺎﺟﺔ ﻷن ﺗﻘﻮم وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﺑﺪ ور ﻗﯿﺎدي وذات أﺛﺮ ﻓﻌﺎل ﺑﺸﻜﻞ ﺧﺎص. ﺗﺸﺠﱠ ﻊ وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ ﻋﻠﻰ ﻣﺮاﺟﻌﺔ اﻟﻤﻤﺎرﺳﺎت واﻟﺴﯿﺎﺳﺎت اﻟﻘﺎﺋﻤﺔ وﻣﺴﺎﻋﺪة ﻣﻨ ﺎطﻘﮭﺎ ﻋﻠﻰ ﻓﮭﻢ أﻧﻮاع اﻟﻤﻤﺎرﺳﺎت اﻟﺘﻲ ﺳﺘﺘﻮاﻓﻖ ﻣﻊ ﻣﺘﻄﻠﺒﺎت اﻟﻮﻻﯾﺔ ﺑﺨﺼﻮص اﻟﺘﺴﺠﯿﻞ ﺑﺎﻟﻤﺪارس ﻣﻦ دون أن ﺗﺨﺎﻟﻒ ﻣﺘﻄﻠﺒﺎت ﻋﺪم اﻟﺘﻤﯿﯿﺰ اﻟﺪﺳﺘﻮرﯾﺔ واﻟﻔﺪراﻟﯿﺔ. وﺑﺸﻜﻞ ﻣﺤﺪد، ﯾﺠﺐ ﻋﻠﻰ وﻛﺎﻻت اﻟﺘﻌﻠﯿﻢ ﻓﻲ اﻟﻮﻻﯾﺔ اﻟﻌﻤﻞ ﻋﻠﻰ اﻟﺘﺄﻛﺪ ﻣﻦ أن ﻣﻤﺎرﺳﺎت اﻟﺘﺴﺠﯿﻞ اﻟﻤﺘﺒﻌﺔ ﻓﻲ ﻣﻨﺎطﻘﮭﺎ اﻟﺘﻌﻠﯿﻤﯿ ﺔ ﻻ ﺗﻌﯿﻖ أو ﺗﻤﻨﻊ اﻟﻄﻠﺒﺔ ﺑﺸﻜﻞ ﻏﯿﺮ ﻗﺎﻧﻮﻧﻲ ﻋﻦ اﻟﻤﺪرﺳﺔ، ﺑﻤﺎ ﻓﻲ ذﻟﻚ اﻟ ﻄﻼب أو آﺑﺎ ؤ ھﻢ اﻟﺬﯾﻦ ﻻ ﯾﺤﻤﻠﻮن وﺛﺎﺋﻖ ﻗﺎﻧﻮﻧﯿﺔ. اﻟﺼﯿﻐﺔ اﻟﻤﻨﻘﺤﺔ ﻓﻲ ﺷﮭﺮ ﻣﺎﯾﻮ/ أﯾﺎر 2014 5
    
    Translated Text saved to 'translated_to_french.txt':
    Le Ministère de la justice, le Ministère de l &apos; éducation, le Ministère de l &apos; éducation, le Ministère de l &apos; éducation, le Département des droits des villes, le Bureau des droits des villes et de l &apos; information sur le droit des enfants de s &apos; inscrire à l &apos; école: questions et réponses aux questions et aux régions d &apos; apprentissage du Nouveau-Balau et aide les États et les régions d &apos; apprentissage à s &apos; acquitter des obligations qui leur incombent en vertu de la loi afin de s &apos; assurer que la loi et les pratiques relatives à l &apos; inscription des enfants dans les écoles publiques au niveau primaire et secondaire ne sont pas fondées sur la race, la couleur ou l &apos; origine nationale. Le Ministère de la justice et le Ministère de l &apos; éducation encouragent ou découragent l &apos; inscription d &apos; élèves à l &apos; école primaire et secondaire sur la base d &apos; un statut d &apos; élève réel ou perçu comme tel. Le Ministère de la justice et le Ministère de l &apos; éducation encouragent les États et les zones d &apos; exécution de manière à ce qu &apos; ils continuent d &apos; appliquer des pratiques d &apos; enregistrement et des pratiques d &apos; appui à l &apos; enregistrement, qui créent une concentration d &apos; étudiants et de personnes de plus en plus nombreuses La loi no 42 de l'ordonnance no 11301 relative à l'aide aux sans-abri, McNee-Vincent-et-les-Grâce, stipule que les personnes déplacées peuvent s'acquitter de leurs obligations pour indiquer qu'elles résident dans la zone scolaire? C Une copie d'une somme d'argent pour le paiement du loyer, ou une lettre de l'employé d'un père ou d'un tuteur écrit sur le papier de l'entreprise. Un parent ou le tuteur de l'ordre doit être autorisé à prouver qu'il réside par l'un quelconque des moyens de remplacement prévus par la législation locale ou la loi de la wala. Par sa lettre du 6 mai 2011 sur le droit d'inscrire des enfants à l'école, l'UNICEF a mis à jour cette documentation pour répondre à des questions supplémentaires qui ont été reçues depuis la lettre de 2011 de l'Organisation des Nations Unies sur le droit à l'éducation, la science et la culture (UNESCO). La région doit revoir la liste des documents qui ont pu être utilisés pour établir la résidence afin de s'assurer que les documents requis n'interdisent pas ou n'interdisent pas de manière illégale tout élève de l'école qui est étudiant, père ou premier directeur de l'école. Par exemple, le choix de la zone délivré par le wali ou le permis de conduire délivré par l'un des parents ou par le tuteur de l'ordre de résidence, ne peut pas faire l'objet d'une demande de permis de séjour comme celle-ci. Pour d'autres raisons, cette demande a pu interdire de manière illégale à un étudiant qui n'avait pas de papiers pour s'inscrire à l'école. À l'école, même si les documents requis pour établir la résidence n'ont pas été mis en évidence. La loi McNee-Vonto définit le terme"enfants et jeunes sans-abri" comme incluant, en partie,"enfants et jeunes garçons ont partagé avec d'autres personnes des logements qui leur sont chers, des difficultés économiques, ou des raisons similaires; 'Ashawn est mort, des hôtels, des parcs de caravanes ou des lieux de tourbillon, étant donné qu'il n'y a pas de logement en remplacement approprié; 'Aishon se trouve dans des abris d'urgence ou doit être transféré; elle est abandonnée à l'hôpital; ou encore elle attend d'être placée sous la garde d'enfants à l'hameçon." Des informations supplémentaires sont disponibles sur le site gov/programs/homeless/guidance. pdf (www. ed. o. g. 5). Comment les personnes déplacées peuvent-elles être tenues de respecter les conditions d'âge scolaire? C Les documents de remplacement peuvent comprendre, mais pas seulement, les documents suivants: Shadow Downa, un médecin de l'hôpital ou de l'infirmerie de Tarkh; Codna dans la Bible de la famille; un dossier d'adoption; une déclaration de police accompagnée d'un parent ou d'un tuteur; Shada Milad, les registres d'une ancienne école ont été vérifiés; ou tout autre document de loi. L'essentiel de mon avenir est de s'inscrire et de rester à l'école, y compris l'élève qui n'a pas de documents juridiques, ou l'enfant ou le jeune sans-abri, comme prévu dans la loi McNee-Vonto (voir S4 ci-dessus), la zone d'apprentissage n'est pas autorisée à empêcher ou décourager un élève de rester à l'école parce que l'élève n'a pas le droit de porter les dossiers de Chevalier à la naissance, par exemple à l'étranger. La loi de 1964 sur les droits des villes, qui a été mise en œuvre par le Ministère de la justice, dispose que la région d'apprentissage n'est pas habilitée à prendre des mesures pour priver les étudiants de la protection égale qui leur est accordée par les lois de 1964. La loi de 1964 sur les droits des villes, qui a été appliquée par le Ministère de l'éducation, et par le Ministère de la justice après avoir été transférée par l'agence de financement du Fed en intervenant dans une procédure en cours, interdit les mutilations sur la base de la race. En outre, il est possible que des demandes comme celle-ci n'encouragent pas l'inscription d'une pipe ou d'une étudiante sur la base du statut d'un élève, d'un père, d'un père ou d'un autre membre de la famille. Les zones d'apprentissage sont encouragées à prendre des mesures préventives en vue de sensibiliser l'AB aux droits des enfants et de les rassurer sur le fait que les enfants de l'AE sont les bienvenus dans les régions d'apprentissage. À titre d'exemple, les Gouanes permettent généralement à la région d'utiliser différents documents pour prouver l'âge de l'enfant. Comme on l'a vu plus haut, un enfant né dans un pays étranger, un gamin capable ou un garé qui veut donner un sédatif à Milad, doit avoir le même choix que les autres à l'école et ne pas être traité de la même manière que l'enfant sexuel, ni comme un roi, ni d'une autre manière, ne peut pas mettre en évidence l'existence d'un mollusque. Le gouvernement n'empêche pas les wallats ou les régions d'obtenir le numéro de la sécurité sociale pour l'avenir. Cependant, les walaises et les zones d'apprentissage doivent décider si elles ont une raison plus légitime d'utiliser l'Ionaq et d'obtenir cette information. Si les chiffres de la sécurité sociale sont obtenus, il faut prendre des mesures pour garantir que les chiffres de la sécurité sociale soient enregistrés en toute sécurité. Par exemple, si une région demande des chiffres de la sécurité sociale, les individus doivent indiquer: 'Kon Toa', et il faut expliquer les causes de la demande de chiffres &apos;. &gt; &gt; et comment la région utilisera ces chiffres. Voir la loi spéciale de 1974, Bulletin L. 579-93, partie 5 et la loi d &apos; ordonnance no 7-552, note disponible à l &apos; adresse suivante: http://www. ssa. gov/OP_Home/comp2/F093-579. html. Comme l &apos; indique la lettre d &apos; isolation, la région ne peut pas refuser l &apos; inscription d &apos; un étudiant s &apos; il choisit &lt; &lt; ♪ &gt; &gt;, ou &lt; &lt; ♪ &gt;, ou &lt; ♪ &gt;, ou &lt; &lt; ♪ &gt;, ou &lt;. Par exemple, si la région veut que les étudiants portent des chiffres, elle peut donner à chaque élève un numéro qui a été choisi par diapositive. Ainsi, la wala ou la région évite tout effet de contrainte qui pourrait laisser la demande de chiffres de sécurité sociale sur l'enregistrement des étudiants par race, couleur, origine nationale, sexe ou position de la zone d'apprentissage qui préfère la demande de chiffres de sécurité sociale, devrait être expliquée dans tous les documents d'enregistrement, y compris S. Le choix de ne pas fournir le numéro de la sécurité sociale n'empêchera pas l'enfant de s'inscrire. La région ne peut pas refuser le droit de s'inscrire si le père d'Eh ou le père d'Ah choisit de ne pas fournir le numéro de sécurité sociale de ' ou de '. Les lois fédérales et les lois de l'Olivia, y compris l'obligation de ne pas le faire, n'ont pas d'effet sur l'esclavage, la couleur ou l'origine nationale. Afin d'éviter toute perturbation de l'activité de l'enregistrement, il est nécessaire que toute région d'apprentissage enregistre l'enfant qui vient d'arriver et demande des documents plus tard, une fois que l'enfant aura été enregistré. Cependant, les régions peuvent aussi choisir d'attendre et de ne pas demander de documents supplémentaires qui pourraient être requis en vertu de la loi sur les walis ou de lois fédérales, comme les boîtiers de la ddémographe, sauf si les étudiants sont inscrits. ♪ Les exigences de l'Apocalypse ne doivent pas avoir d'incidence sur l'apprentissage sans le consentement d'un étudiant, d'un père ou d'un tuteur ♪ ♪ ♪ Il y a des circonstances dans lesquelles il est possible de divulguer des informations sur l'apprentissage sans le consentement d'un étudiant, d'un père ou d'un tuteur ♪ ♪ ♪ ♪ ♪ Il y a des circonstances dans la zone d'apprentissage ♪ La loi de 1974 sur le droit à l &apos; éducation et le droit à l &apos; éducation des familles (FERPA) interdit en général aux zones d &apos; études qui reçoivent du Ministère de l &apos; éducation un financement fédéral de divulguer des informations provenant des registres d &apos; apprentissage des élèves, qui sont seuls ou en commun avec d &apos; autres informations, d &apos; identifier l &apos; élève, sans l &apos; accord d &apos; un parent, d &apos; un tuteur ou d &apos; un étudiant, s &apos; il est âgé de 18 ans ou s &apos; il est né dans un établissement d &apos; enseignement supérieur après la deuxième année d &apos; études. Les exceptions limitées prévues dans la loi de 1974 sur le droit à l &apos; éducation des familles concernant la demande d &apos; approbation préalable à la divulgation d &apos; informations permettant d &apos; identifier une personne se trouvant dans les registres de l &apos; élève, voir la loi fédérale 34 (sect. 99. 31), ainsi que les circonstances limitées et limitées dans lesquelles la demande a été faite, conformément à la loi fédérale de 1974 relative à l &apos; obligation d &apos; obtenir l &apos; approbation du plan, permettent à la zone d &apos; apprentissage d &apos; obtenir des informations précises sur une autre entité publique fédérale, locale ou de l &apos; État. L &apos; une de ces circonstances est l &apos; émission d &apos; un signe d &apos; agressivité à l &apos; intention d &apos; un étudiant et le maintien d &apos; un statut d &apos; abandon. Dans ce cas, la région dispose d'informations préalables sur l'élève qui a présenté à l'école un document de base pour l'inscription, étant donné que l'école n'a aucune raison de demander des informations sur le statut de l'enfant. ♪ L'école, par exemple, doit fournir des informations fondamentales et fiables sur les inscriptions en langue gaélique ♪ ♪ La région doit communiquer les informations essentielles sur les inscriptions ♪ ♪ ♪ ♪ Par exemple, elle traduit la confiance en langues gaélique ♪ ♪ ♪ ♪ ♪ ♪ et la réponse de Neubala aux questions ♪ ♪ ♪ ♪ ♪ est requise ♪ ♪ ♪ dans la section VI de la loi sur les droits urbains de 1964 ♪ ♪ ♪ ♪ ♪ ♪ la loi édicte la loi ♪ Kei42 ♪ ♪ ♪ ♪ ♪ and the law of Equal Education opportunity ♪ ♪ ♪ ♪ La loi sur l'égalité des chances d'apprentissage 20 ♪ ♪ Si la région demande un numéro de sécurité sociale, il se peut qu'il y ait des informations de base qui indiquent que la région n'est pas la version révisée de Ma'u et/ou Aguar 2014 4T. Si l'étudiant ou l'étudiant choisit de s'inscrire, le père ou le premier (ne fournit pas le numéro de sécurité sociale). En outre, le Ministère de l &apos; éducation de l &apos; Europe et le Ministère de la justice encouragent les régions à prendre l &apos; initiative d &apos; informer les parents de leur droit d &apos; envoyer des enfants dans une école publique. Les régions peuvent, par exemple, communiquer avec les communautés pour faire savoir à l &apos; opinion publique que l &apos; ensemble des élèves de la région sont bien accueillis dans les écoles de la région. Le rôle des agences d &apos; apprentissage de la Vallée (SEA) est de veiller à ce que les élèves ne soient pas exclus de l &apos; école d &apos; une manière disproportionnée. Les deux lois relatives à l'inscription à l'école, y compris les exigences en matière d'établissement de l'âge et de résidence, varient d'un pays à l'autre, et il est donc nécessaire que les agences d'apprentissage des États de la vallée de War Qadi aient un effet particulièrement efficace. Les agences d'apprentissage des États sont encouragées à revoir les pratiques et les statuts existants et à contribuer à la compréhension de ces pratiques. Plus précisément, les agences d'enseignement des États doivent veiller à ce que les pratiques d'inscription dans les zones d'apprentissage ne gênent pas ou n'interdisent pas illégalement les élèves de l'école, y compris les élèves ou les parents, et ne portent pas de documents de loi.
    
    Statistics:
      Extracted Text: 2913 words, 16783 characters, 114 sentences
      Translated Text: 2194 words, 13513 characters, 625 sentences